import { Language, Library } from "../../languages";
/**
 * Enum for generator directories for non-client generators
 */
export declare enum NonClientGeneratorDirectory {
    DOCS = "docs"
}
/**
 * Generator directory for openapi generation containing templates, config etc.
 */
export type GeneratorDirectory = Language | NonClientGeneratorDirectory | Library;
/**
 * Types of normalizers supported by openapi-generator
 * @see https://openapi-generator.tech/docs/customization/#openapi-normalizer
 */
export type OpenApiNormalizer = "KEEP_ONLY_FIRST_TAG_IN_OPERATION";
/**
 * Options for generating client code or docs using OpenAPI Generator CLI
 */
export interface GenerationOptions {
    /**
     * The OpenAPI generator to use to generate the code/docs
     */
    readonly generator: string;
    /**
     * The directory to use for OpenAPI generation
     */
    readonly generatorDirectory: GeneratorDirectory;
    /**
     * The path of the OpenAPI spec to generate the client for
     */
    readonly specPath: string;
    /**
     * The directory in which the generated code should be output
     */
    readonly outputPath: string;
    /**
     * Additional properties to pass to the generate cli
     */
    readonly additionalProperties?: {
        [key: string]: string;
    };
    /**
     * Supply the relative path from the code project root to the source code directory in which custom generated files
     * (eg. operation config) should be placed.
     */
    readonly srcDir?: string;
    /**
     * Normalizers to apply to the spec prior to generation, if any
     * @see https://openapi-generator.tech/docs/customization/#openapi-normalizer
     */
    readonly normalizers?: Partial<Record<OpenApiNormalizer, boolean>>;
}
export interface CommandDetails {
    readonly command: string;
    readonly workingDir: string;
}
/**
 * Generate client code or docs by invoking the root generate script
 */
export declare const buildInvokeOpenApiGeneratorCommand: (options: GenerationOptions) => CommandDetails;
export declare const buildCleanOpenApiGeneratedCodeCommand: (outdir: string) => CommandDetails;
/**
 * Options for generating documentation via a custom generator script
 */
export interface CustomDocsGenerationOptions {
    /**
     * Name of the generator script which exists in scripts/custom/docs
     */
    readonly generator: string;
    /**
     * The path of the OpenAPI spec to generate the client for
     */
    readonly specPath: string;
    /**
     * The directory in which the generated code should be output
     */
    readonly outputPath: string;
}
/**
 * Invoke a custom documentation generator script
 */
export declare const buildInvokeCustomDocsGeneratorCommand: (options: CustomDocsGenerationOptions) => CommandDetails;
export interface GenerateCdkInfrastructureOptions {
    /**
     * Path to the openapi specification, relative to the source path
     */
    readonly specPath: string;
    /**
     * Absolute path to the source directory of the package in which to generate the cdk infrastructure
     */
    readonly sourcePath: string;
    /**
     * Absolute path to the resources directory of the package in which to generate resources (java only)
     */
    readonly resourcePath?: string;
    /**
     * Language to generate cdk infrastructure in
     */
    readonly language: Language;
    /**
     * Package name for the cdk infrastructure
     */
    readonly infraPackage: string;
    /**
     * Generated types package name for importing the generated types
     */
    readonly generatedTypesPackage: string;
}
export declare const buildGenerateCdkInfrastructureCommand: (options: GenerateCdkInfrastructureOptions) => CommandDetails;
