## Type Safe API

Define your APIs using [Smithy](https://smithy.io/2.0/) or [OpenAPI v3](https://swagger.io/specification/), and leverage the power of generated client and server types, infrastructure, documentation, and automatic input validation!

This package vends a projen project type which allows you to define an API using either [Smithy](https://smithy.io/2.0/) or [OpenAPI v3](https://swagger.io/specification/), and a construct which manages deploying this API in API Gateway, given an integration (eg a lambda) for every operation.

The project will generate "runtime" projects from your API definition in your desired languages, which can be utilised both client side for interacting with your API, or server side for implementing your API. The project also generates a type-safe CDK construct which ensures an integration is provided for every API operation.

Code is generated at build time, so when you change your API model, just rebuild and you'll see your changes reflected in the generated code.

### Quick Start: TypeScript

This section describes how to get started quickly, with TypeScript infrastructure and lambda handlers. See the end of the README for examples in [Python](#quick-start--python) and [Java](#quick-start--python).

#### Create Your API Project

Use the project in your `.projenrc.ts`. It can either be part of an [`nx-monorepo`](../nx-monorepo/README.md) (recommended) or used in a standalone fashion.

```python
# Example automatically generated from non-compiling source. May contain errors.
from aws_prototyping_sdk.nx_monorepo import NxMonorepoProject
from aws_prototyping_sdk.type_safe_api import TypeSafeApiProject
from projen.awscdk import AwsCdkTypeScriptApp

# Create the monorepo
monorepo = NxMonorepoProject(...)

# Create the API project
api = TypeSafeApiProject(
    name="myapi",
    parent=monorepo,
    outdir="packages/api",
    # Smithy as the model language. You can also use ModelLanguage.OPENAPI
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                }
            }
        }
    },
    # Generate types, client and server code in TypeScript, Python and Java
    runtime={
        "languages": [Language.TYPESCRIPT, Language.PYTHON, Language.JAVA]
    },
    # CDK infrastructure in TypeScript
    infrastructure={
        "language": Language.TYPESCRIPT
    },
    # Generate HTML documentation
    documentation={
        "formats": [DocumentationFormat.HTML_REDOC]
    },
    # Generate react-query hooks to interact with the UI from a React website
    library={
        "libraries": [Library.TYPESCRIPT_REACT_QUERY_HOOKS]
    }
)

# Create a CDK infrastructure project. Can also consider PDKPipelineTsProject as an alternative!
infra = AwsCdkTypeScriptApp(...)

# Infrastructure can depend on the generated API infrastructure and runtime
infra.add_deps(api.infrastructure.typescript.package.package_name)
infra.add_deps(api.runtime.typescript.package.package_name)

monorepo.synth()
```

#### Use the CDK Construct

In your CDK application (ie within the `infra` project we created), consume the `Api` construct, vended from the generated typescript infrastructure package.

```python
# Example automatically generated from non-compiling source. May contain errors.
from aws_cdk import Stack, StackProps
from constructs import Construct
from myapi_typescript_infra import Api # <- generated typescript infrastructure package
from aws_prototyping_sdk.type_safe_api import Authorizers, Integrations
from aws_cdk.aws_lambda_nodejs import NodejsFunction
from aws_cdk.aws_apigateway import Cors
import path as path

class MyStack(Stack):
    def __init__(self, scope, id, *, description=None, env=None, stackName=None, tags=None, synthesizer=None, terminationProtection=None, analyticsReporting=None, crossRegionReferences=None, permissionsBoundary=None):
        super().__init__(scope, id, description=description, env=env, stackName=stackName, tags=tags, synthesizer=synthesizer, terminationProtection=terminationProtection, analyticsReporting=analyticsReporting, crossRegionReferences=crossRegionReferences, permissionsBoundary=permissionsBoundary)

        # Instantiate the generated CDK construct to deploy an API Gateway API based on your model
        Api(self, "MyApi",
            default_authorizer=Authorizers.iam(),
            cors_options={
                "allow_origins": Cors.ALL_ORIGINS,
                "allow_methods": Cors.ALL_METHODS
            },
            # Supply an integration for every operation
            integrations={
                "say_hello": {
                    "integration": Integrations.lambda_(
                        NodejsFunction(self, "SayHelloLambda",
                            entry=path.resolve(__dirname, "say-hello.ts")
                        ))
                }
            }
        )
```

#### Implement a Lambda Handler

The generated runtime projects include lambda handler wrappers which provide type-safety for implementing your API operations. You can implement your lambda handlers in any of the supported languages, and even mix and match languages for different operations if you like.

In the above CDK application, we used `NodejsFunction` with the entry point as `say-hello.ts`, so we can define the lambda function in the same `infra` project.

In typescript, the implementation of `say-hello.ts` would look like:

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import say_hello_handler # <- generated typescript runtime package

# Use the handler wrapper for type-safety to ensure you correctly implement your modelled API operation
handler = say_hello_handler(async ({ input }) => {
      return {
        statusCode: 200,
        body: {
          message: `Hello ${input.requestParameters.name}`,
        },
      };
    })
```

### Project

The `TypeSafeApiProject` projen project sets up the project structure for you. You have a few parameters to consider when creating the project:

* `model` - Configure the API model. Select a `language` for the model of either [Smithy](https://smithy.io/2.0/) or [OpenAPI v3](https://swagger.io/specification/), and supply `options.smithy` or `options.openapi` depending on your choice.
* `runtime` - Configure the generated runtime projects. Include one or more `languages` you wish to write your client and server-side code in. These projects contain generated types defined in your model, as well as type-safe lambda handler wrappers for implementing each operation.
* `infrastructure` - Pick the `language` you are writing your CDK infrastructure in. A construct will be generated in this language which can be used to deploy the API.
* `documentation` - Specify `formats` to generate documentation in.

It's recommended that these projects are used as part of an `nx-monorepo` project (eg. by specifying `parent: myMonorepoProject`), as it makes setting up dependencies much easier, particularly when extending your project further with a CDK app and lambda functions.

Depending on the `model.language` you choose, you must supply the corresponding `model.options`. For example:

```python
# Example automatically generated from non-compiling source. May contain errors.
TypeSafeApiProject(
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                }
            }
        }
    }, ...
)
```

```python
# Example automatically generated from non-compiling source. May contain errors.
TypeSafeApiProject(
    model={
        "language": ModelLanguage.OPENAPI,
        "options": {
            "openapi": {
                "title": "MyApi"
            }
        }
    }, ...
)
```

`model.options.smithy` allows for further customisation of the Smithy project, eg:

```python
# Example automatically generated from non-compiling source. May contain errors.
TypeSafeApiProject(
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                },
                # By default, the contents of the smithy build output directory `model/output` will be ignored by source control.
                # Set this to false to include it, for example if you are generating clients directly from the smithy model.
                "ignore_smithy_build_output": False,
                # The gradle wrapper used for the smithy build is copied from the PDK itself if it does not already exist in
                # the 'smithy' folder. By default, this gradle wrapper will be ignored by source control.
                # Set this to false if you would like to check the gradle wrapper in to source control, for example if you want
                # to use a different version of the gradle wrapper in your project.
                "ignore_gradle_wrapper": False,
                # Use smithyBuildOptions to control what is added to smithy-build.json.
                "smithy_build_options": {
                    "projections": {
                        # You can customise the built-in openapi projection, used to generate the OpenAPI specification.
                        "openapi": {
                            "plugins": {
                                "openapi": {
                                    # Customise the openapi projection here.
                                    # See: https://smithy.io/2.0/guides/converting-to-openapi.html
                                    "use_integer_type": True, ...
                                }
                            }
                        },
                        # You can add new projections here too
                        "ts-client": {
                            "plugins": {
                                "typescript-codegen": {
                                    "package": "@my-test/smithy-generated-typescript-client",
                                    "package_version": "0.0.1"
                                }
                            }
                        }
                    },
                    # Note that any additional dependencies required for projections/plugins can be added here, which in turn will
                    # add them to the `smithy/build.gradle` file
                    "maven": {
                        "dependencies": ["software.amazon.smithy:smithy-validation-model:1.27.2"
                        ]
                    }
                }
            }
        }
    }, ...
)
```

#### Directory Structure

The `TypeSafeApiProject` will create the following directory structure within its `outdir`:

```
|_ model/
    |_ src/
        |_ main/
            |_ smithy - your API definition if you chose ModelLanguage.SMITHY
            |_ openapi - your API definition if you chose ModelLanguage.OPENAPI
|_ runtime/ - generated types, client, and server code in the languages you specified
    |_ typescript
    |_ python
    |_ java
|_ infrastructure/ - generated infrastructure (you'll find only one directory in here based on your chosen infrastructure language)
    |_ typescript
    |_ python
    |_ java
|_ documentation/ - generated documentation in the formats you specified
    |_ html2
    |_ html_redoc
    |_ plantuml
    |_ markdown
|_ library/ - generated libraries if specified
    |_ typescript-react-query-hooks
```

### Smithy IDL

Please refer to the [Smithy documentation](https://smithy.io/2.0/quickstart.html) for how to write models in Smithy. A basic example is provided below:

```smithy
$version: "2"
namespace example.hello

use aws.protocols#restJson1

@title("A Sample Hello World API")

/// A sample smithy api
@restJson1
service Hello {
    version: "1.0"
    operations: [SayHello]
}

@readonly
@http(method: "GET", uri: "/hello")
operation SayHello {
    input: SayHelloInput
    output: SayHelloOutput
    errors: [ApiError]
}

string Name
string Message

@input
structure SayHelloInput {
    @httpQuery("name")
    @required
    name: Name
}

@output
structure SayHelloOutput {
    @required
    message: Message
}

@error("client")
structure ApiError {
    @required
    errorMessage: Message
}
```

#### Supported Protocols

Currently only [AWS restJson1](https://smithy.io/2.0/aws/protocols/aws-restjson1-protocol.html) is supported. Please ensure your service is annotated with the `@restJson1` trait.

#### Multiple Files

You can split your definition into multiple files and folders, so long as they are all under the `model/src/main/smithy` directory in your API project.

#### Authorizers

Smithy supports [adding API Gateway authorizers in the model itself](https://smithy.io/2.0/aws/aws-auth.html). Given that at model definition time one usually does not know the ARN of the user pool or lambda function for an authorizer, it is recommended to add the authorizer(s) in your Api CDK construct.

If using Smithy generated clients, some authorizer traits (eg sigv4) will include configuring the client for that particular method of authorization, so it can be beneficial to still define authorizers in the model. We therefore support specifying authorizers in both the model and the construct, but note that the construct will take precedence where the authorizer ID is the same.

### OpenAPI Specification

Your `model/src/main/openapi/main.yaml` file defines your api using [OpenAPI Version 3.0.3](https://swagger.io/specification/). An example spec might look like:

```yaml
openapi: 3.0.3
info:
  version: 1.0.0
  title: Example API
paths:
  /hello:
    get:
      operationId: sayHello
      parameters:
        - in: query
          name: name
          schema:
            type: string
          required: true
      responses:
        "200":
          description: Successful response
          content:
            "application/json":
              schema:
                $ref: "#/components/schemas/HelloResponse"
components:
  schemas:
    HelloResponse:
      type: object
      properties:
        message:
          type: string
      required:
        - message
```

You can divide your specification into multiple files using `$ref`.

For example, you might choose to structure your spec as follows:

```
|_ model/src/main/openapi/
    |_ main.yaml
    |_ paths/
        |_ index.yaml
        |_ sayHello.yaml
    |_ schemas/
        |_ index.yaml
        |_ helloResponse.yaml
```

Where `main.yaml` looks as follows:

```yaml
openapi: 3.0.3
info:
  version: 1.0.0
  title: Example API
paths:
  $ref: "./paths/index.yaml"
components:
  schemas:
    $ref: "./schemas/index.yaml"
```

`paths/index.yaml`:

```yaml
/hello:
  get:
    $ref: "./sayHello.yaml"
```

`paths/sayHello.yaml`:

```yaml
operationId: sayHello
parameters:
  - in: query
    name: name
    schema:
      type: string
    required: true
responses:
  "200":
    description: Successful response
    content:
      "application/json":
        schema:
          $ref: "../schemas/helloResponse.yaml"
```

`schemas/index.yaml`:

```yaml
HelloResponse:
  $ref: "./helloResponse.yaml"
```

`schemas/helloResponse.yaml`:

```yaml
type: object
properties:
  message:
    type: string
required:
  - message
```

### Construct

A CDK construct is generated in the `infrastructure/<language>` directory which provides a type-safe interface for creating an API Gateway API based on your model.

You can extend or instantiate this construct in your CDK infrastructure project. You'll get a type error if you forget to define an integration for an operation defined in your api.

```python
# Example automatically generated from non-compiling source. May contain errors.
from aws_prototyping_sdk.type_safe_api import Authorizers, Integrations
from aws_cdk.aws_lambda_nodejs import NodejsFunction
from constructs import Construct
from myapi_typescript_infra import Api

#
# An example of how to wire lambda handler functions to the API
#
class SampleApi(Api):
    def __init__(self, scope, id):
        super().__init__(scope, id,
            default_authorizer=Authorizers.iam(),
            integrations={
                # Every operation defined in your API must have an integration defined!
                "say_hello": {
                    "integration": Integrations.lambda_(
                        NodejsFunction(scope, "say-hello"))
                }
            }
        )
```

#### Sharing Integrations

If you would like to use the same integration for every operation (for example you'd like to use a single lambda function to service all requests with the in-built [handler router](#handler-router)), you can use the `Operations.all` method from a generated runtime project to save repeating yourself:

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import Operations
from aws_prototyping_sdk.type_safe_api import Authorizers, Integrations
from aws_cdk.aws_lambda_nodejs import NodejsFunction
from constructs import Construct
from myapi_typescript_infra import Api

class SampleApi(Api):
    def __init__(self, scope, id):
        super().__init__(scope, id,
            default_authorizer=Authorizers.iam(),
            # Use the same integration for every operation.
            integrations=Operations.all(
                integration=Integrations.lambda_(NodejsFunction(scope, "router"))
            )
        )
```

TypeScript is demonstrated above, but this is also available in Java and Python.

#### Authorizers

The `Api` construct allows you to define one or more authorizers for securing your API. An integration will use the `defaultAuthorizer` unless an `authorizer` is specified at the integration level. The following authorizers are supported:

* `Authorizers.none` - No auth
* `Authorizers.iam` - AWS IAM (Signature Version 4)
* `Authorizers.cognito` - Cognito user pool
* `Authorizers.custom` - A custom authorizer

##### Cognito Authorizer

To use the Cognito authorizer, one or more user pools must be provided. You can optionally specify the scopes to check if using an access token. You can use the `withScopes` method to use the same authorizer but verify different scopes for individual integrations, for example:

```python
# Example automatically generated from non-compiling source. May contain errors.
class SampleApi(Api):
    def __init__(self, scope, id):
        cognito_authorizer = Authorizers.cognito(
            authorizer_id="myCognitoAuthorizer",
            user_pools=[UserPool(scope, "UserPool")]
        )

        super().__init__(scope, id,
            default_authorizer=cognito_authorizer,
            integrations={
                # Everyone in the user pool can call this operation:
                "say_hello": {
                    "integration": Integrations.lambda_(
                        NodejsFunction(scope, "say-hello"))
                },
                # Only users with the given scopes can call this operation
                "my_restricted_operation": {
                    "integration": Integrations.lambda_(
                        NodejsFunction(scope, "my-restricted-operation")),
                    "authorizer": cognito_authorizer.with_scopes("my-resource-server/my-scope")
                }
            }
        )
```

For more information about scopes or identity and access tokens, please see the [API Gateway documentation](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-integrate-with-cognito.html).

##### Custom Authorizer

Custom authorizers use lambda functions to handle authorizing requests. These can either be simple token-based authorizers, or more complex request-based authorizers. See the [API Gateway documentation](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-use-lambda-authorizer.html) for more details.

An example token-based authorizer (default):

```python
# Example automatically generated from non-compiling source. May contain errors.
Authorizers.custom(
    authorizer_id="myTokenAuthorizer",
    function=NodejsFunction(scope, "authorizer")
)
```

An example request-based handler. By default the identitySource will be `method.request.header.Authorization`, however you can customise this as per [the API Gateway documentation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource).

```python
# Example automatically generated from non-compiling source. May contain errors.
Authorizers.custom(
    authorizer_id="myRequestAuthorizer",
    type=CustomAuthorizerType.REQUEST,
    identity_source="method.request.header.MyCustomHeader, method.request.querystring.myQueryString",
    function=NodejsFunction(scope, "authorizer")
)
```

#### Integrations

Integrations are used by API Gateway to service requests.

##### Lambda Integration

Currently, the only built-in integration is a lambda integration. You can construct one using `Integrations.lambda(yourLambdaFunction)`.

##### Custom Integrations

You can implement your own integrations by inheriting the `Integration` class and implementing its `render` method. This method is responsible for returning a snippet of OpenAPI which will be added as the `x-amazon-apigateway-integration` for an operation. Please refer to the [API Gateway Swagger Extensions documentation](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration.html) for more details.

You can also optionally override the `grant` method if you need to use CDK to grant API Gateway access to invoke your integration.

### Runtime: Clients

The generated runtime projects include clients which can be used for type-safe interaction with your API.

#### Typescript

The [typescript-fetch](https://openapi-generator.tech/docs/generators/typescript-fetch/) OpenAPI generator is used to generate typescript client. This requires an implementation of `fetch` to be passed to the client. In the browser one can pass the built in fetch, or in NodeJS you can use an implementation such as [node-fetch](https://www.npmjs.com/package/node-fetch).

Example usage of the client in a website:

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import Configuration, DefaultApi

client = DefaultApi(
    Configuration(
        base_path="https://xxxxxxxxxx.execute-api.ap-southeast-2.amazonaws.com",
        fetch_api=window.fetch.bind(window)
    ))

client.say_hello(name="Jack")
```

#### Python

The [python](https://openapi-generator.tech/docs/generators/python) OpenAPI generator is used to generate clients for python.

Example usage:

```python
from myapi_python_runtime import ApiClient, Configuration
from myapi_python_runtime.api.default_api import DefaultApi

configuration = Configuration(
    host = "https://xxxxxxxxxx.execute-api.ap-southeast-2.amazonaws.com"
)

with ApiClient(configuration) as api_client:
    client = DefaultApi(api_client)

    client.say_hello(
        query_params={
            'name': "name_example",
        },
    )
```

You'll find details about how to use the python client in the README.md in your generated runtime project.

#### Java

The [java](https://openapi-generator.tech/docs/generators/java/) OpenAPI generator is used to generate clients for Java.

Example usage:

```java
import com.generated.api.myapijavaruntime.runtime.api.DefaultApi;
import com.generated.api.myapijavaruntime.runtime.ApiClient;
import com.generated.api.myapijavaruntime.runtime.Configuration;
import com.generated.api.myapijavaruntime.runtime.models.HelloResponse;

ApiClient client = Configuration.getDefaultApiClient();
client.setBasePath("https://xxxxxxxxxx.execute-api.ap-southeast-2.amazonaws.com");

DefaultApi api = new DefaultApi(client);
HelloResponse response = api.sayHello("Adrian").execute()
```

You'll find more details about how to use the Java client in the README.md in your generated runtime project.

### Lambda Handler Wrappers

Lambda handler wrappers are also importable from the generated runtime projects. These provide input/output type safety, ensuring that your API handlers return outputs that correspond to your model.

#### Typescript

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import say_hello_handler

handler = say_hello_handler(async ({ input }) => {
      return {
        statusCode: 200,
        body: {
          message: `Hello ${input.requestParameters.name}!`,
        },
      };
    })
```

##### Handler Router

The lambda handler wrappers can be used in isolation as handler methods for separate lambdas. If you would like to use a single lambda function to serve all requests, you can do so with the `handlerRouter`.

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import handler_router, say_hello_handler, say_goodbye_handler
from ..interceptors import cors_interceptor
from ..handlers.say_goodbye import say_goodbye

say_hello = say_hello_handler(async ({ input }) => {
      return {
        statusCode: 200,
        body: {
          message: `Hello ${input.requestParameters.name}!`,
        },
      };
    })

handler = handler_router(
    # Interceptors declared in this list will apply to all operations
    interceptors=[cors_interceptor],
    # Assign handlers to each operation here
    handlers={
        "say_hello": say_hello,
        "say_goodbye": say_goodbye
    }
)
```

#### Python

```python
from myapi_python_runtime.apis.tags.default_api_operation_config import say_hello_handler, SayHelloRequest, ApiResponse, SayHelloOperationResponses
from myapi_python_runtime.model.api_error import ApiError
from myapi_python_runtime.model.hello_response import HelloResponse

@say_hello_handler
def handler(input: SayHelloRequest, **kwargs) -> SayHelloOperationResponses:
    return ApiResponse(
        status_code=200,
        body=HelloResponse(message="Hello {}!".format(input.request_parameters["name"])),
        headers={}
    )
```

##### Handler Router

The lambda handler wrappers can be used in isolation as handler methods for separate lambdas. If you would like to use a single lambda function to serve all requests, you can do so with the `handler_router`.

```python
from myapi_python_runtime.apis.tags.default_api_operation_config import say_hello_handler, SayHelloRequest, ApiResponse, SayHelloOperationResponses, handler_router, HandlerRouterHandlers
from myapi_python_runtime.model.api_error import ApiError
from myapi_python_runtime.model.hello_response import HelloResponse
from other_handlers import say_goodbye
from my_interceptors import cors_interceptor

@say_hello_handler
def say_hello(input: SayHelloRequest, **kwargs) -> SayHelloOperationResponses:
    return ApiResponse(
        status_code=200,
        body=HelloResponse(message="Hello {}!".format(input.request_parameters["name"])),
        headers={}
    )

handler = handler_router(
  # Interceptors defined here will apply to all operations
  interceptors=[cors_interceptor],
  handlers=HandlerRouterHandlers(
    say_hello=say_hello,
    say_goodbye=say_goodbye
  )
)
```

#### Java

```java
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHello;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHello200Response;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHelloRequestInput;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHelloResponse;
import com.generated.api.myapijavaruntime.runtime.model.HelloResponse;


public class SayHelloHandler extends SayHello {
    @Override
    public SayHelloResponse handle(SayHelloRequestInput sayHelloRequestInput) {
        return SayHello200Response.of(HelloResponse.builder()
                .message(String.format("Hello %s", sayHelloRequestInput.getInput().getRequestParameters().getName()))
                .build());
    }
}
```

##### Handler Router

The lambda handler wrappers can be used in isolation as handler methods for separate lambdas. If you would like to use a single lambda function to serve all requests, you can do so by extending the `HandlerRouter` class.

```java
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayGoodbye;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.HandlerRouter;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.Interceptors;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHello;

import java.util.Arrays;
import java.util.List;

// Interceptors defined here apply to all operations
@Interceptors({ TimingInterceptor.class })
public class ApiHandlerRouter extends HandlerRouter {
    // You must implement a method to return a handler for every operation
    @Override
    public SayHello sayHello() {
        return new SayHelloHandler();
    }

    @Override
    public SayGoodbye sayGoodbye() {
        return new SayGoodbyeHandler();
    }
}
```

### Interceptors

The lambda handler wrappers allow you to pass in a *chain* of handler functions to handle the request. This allows you to implement middleware / interceptors for handling requests. Each handler function may choose whether or not to continue the handler chain by invoking `chain.next`.

#### Typescript

In typescript, interceptors are passed as separate arguments to the generated handler wrapper, in the order in which they should be executed. Call `request.chain.next(request)` from an interceptor to delegate to the rest of the chain to handle a request. Note that the last handler in the chain (ie the actual request handler which transforms the input to the output) should not call `chain.next`.

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import say_hello_handler, ChainedRequestInput, OperationResponse

# Interceptor to wrap invocations in a try/catch, returning a 500 error for any unhandled exceptions.
try_catch_interceptor = async <
  RequestParameters,
  RequestArrayParameters,
  RequestBody,
  Response
>(
  request: ChainedRequestInput<
    RequestParameters,
    RequestArrayParameters,
    RequestBody,
    Response
  >
): Promise<Response | OperationResponse<500, { errorMessage: string }>> => {
  try {
    return await request.chain.next(request);
  } catch (e: any) {
    return { statusCode: 500, body: { errorMessage: e.message } };
  }
}

# tryCatchInterceptor is passed first, so it runs first and calls the second argument function (the request handler) via chain.next
handler = say_hello_handler(try_catch_interceptor, async ({ input }) => {
        return {
          statusCode: 200,
          body: {
            message: `Hello ${input.requestParameters.name}!`,
          },
        };
      })
```

Another example interceptor might be to record request time metrics. The example below includes the full generic type signature for an interceptor:

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import ChainedRequestInput

timing_interceptor = async <
  RequestParameters,
  RequestArrayParameters,
  RequestBody,
  Response
>(
  request: ChainedRequestInput<
    RequestParameters,
    RequestArrayParameters,
    RequestBody,
    Response
  >
): Promise<Response> => {
  const start = Date.now();
  const response = await request.chain.next(request);
  const end = Date.now();
  console.log(`Took ${end - start} ms`);
  return response;
}
```

Interceptors may mutate the `interceptorContext` to pass state to further interceptors or the final lambda handler, for example an `identityInterceptor` might want to extract the authenticated user from the request so that it is available in handlers.

```python
# Example automatically generated from non-compiling source. May contain errors.
from myapi_typescript_runtime import LambdaRequestParameters, LambdaHandlerChain

identity_interceptor = async <
  RequestParameters,
  RequestArrayParameters,
  RequestBody,
  Response
>(
  request: ChainedRequestInput<
    RequestParameters,
    RequestArrayParameters,
    RequestBody,
    Response
  >
): Promise<Response> => {
  const authenticatedUser = await getAuthenticatedUser(request.event);
  return await request.chain.next({
    ...request,
    interceptorContext: {
      ...request.interceptorContext,
      authenticatedUser,
    },
  });
}
```

#### Python

In Python, a list of interceptors can be passed as a keyword argument to the generated lambda handler decorator, for example:

```python
from myapi_python_runtime.apis.tags.default_api_operation_config import say_hello_handler, SayHelloRequest, ApiResponse, SayHelloOperationResponses
from myapi_python_runtime.model.api_error import ApiError
from myapi_python_runtime.model.hello_response import HelloResponse

@say_hello_handler(interceptors=[timing_interceptor, try_catch_interceptor])
def handler(input: SayHelloRequest, **kwargs) -> SayHelloOperationResponses:
    return ApiResponse(
        status_code=200,
        body=HelloResponse(message="Hello {}!".format(input.request_parameters["name"])),
        headers={}
    )
```

Writing an interceptor is just like writing a lambda handler. Call `chain.next(input)` from an interceptor to delegate to the rest of the chain to handle a request.

```python
import time
from myapi_python_runtime.apis.tags.default_api_operation_config import ChainedApiRequest, ApiResponse

def timing_interceptor(input: ChainedApiRequest) -> ApiResponse:
    start = int(round(time.time() * 1000))
    response = input.chain.next(input)
    end = int(round(time.time() * 1000))
    print("Took {} ms".format(end - start))
    return response
```

Interceptors may choose to return different responses, for example to return a 500 response for any unhandled exceptions:

```python
import time
from myapi_python_runtime.model.api_error import ApiError
from myapi_python_runtime.apis.tags.default_api_operation_config import ChainedApiRequest, ApiResponse

def try_catch_interceptor(input: ChainedApiRequest) -> ApiResponse:
    try:
        return input.chain.next(input)
    except Exception as e:
        return ApiResponse(
            status_code=500,
            body=ApiError(errorMessage=str(e)),
            headers={}
        )
```

Interceptors are permitted to mutate the "interceptor context", which is a `Dict[str, Any]`. Each interceptor in the chain, and the final handler, can access this context:

```python
def identity_interceptor(input: ChainedApiRequest) -> ApiResponse:
    input.interceptor_context["AuthenticatedUser"] = get_authenticated_user(input.event)
    return input.chain.next(input)
```

Interceptors can also mutate the response returned by the handler chain. An example use case might be adding cross-origin resource sharing headers:

```python
def add_cors_headers_interceptor(input: ChainedApiRequest) -> ApiResponse:
    response = input.chain.next(input)
    return ApiResponse(
        status_code=response.status_code,
        body=response.body,
        headers={
            **response.headers,
            "Access-Control-Allow-Origin": "*",
            "Access-Control-Allow-Headers": "*"
        }
    )
```

#### Java

In Java, interceptors can be added to a handler via the `@Interceptors` class annotation:

```java
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.Interceptors;

@Interceptors({ TimingInterceptor.class, TryCatchInterceptor.class })
public class SayHelloHandler extends SayHello {
    @Override
    public SayHelloResponse handle(SayHelloRequestInput sayHelloRequestInput) {
        return SayHello200Response.of(HelloResponse.builder()
                .message(String.format("Hello %s", sayHelloRequestInput.getInput().getRequestParameters().getName()))
                .build());
    }
}
```

To write an interceptor, you can implement the `Interceptor` interface. For example, a timing interceptor:

```java
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.Interceptor;
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.ChainedRequestInput;
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.Response;

public class TimingInterceptor<Input> implements Interceptor<Input> {
    @Override
    public Response handle(ChainedRequestInput<Input> input) {
        long start = System.currentTimeMillis();
        Response res = input.getChain().next(input);
        long end = System.currentTimeMillis();
        System.out.printf("Took %d ms%n", end - start);
        return res;
    }
}
```

Interceptors may choose to return different responses, for example to return a 500 response for any unhandled exceptions:

```java
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.Interceptor;
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.ChainedRequestInput;
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.Response;
import com.generated.api.myjavaapiruntime.runtime.api.Handlers.ApiResponse;
import com.generated.api.myjavaapiruntime.runtime.model.ApiError;

public class TryCatchInterceptor<Input> implements Interceptor<Input> {
    @Override
    public Response handle(ChainedRequestInput<Input> input) {
        try {
            return input.getChain().next(input);
        } catch (Exception e) {
            return ApiResponse.builder()
                    .statusCode(500)
                    .body(ApiError.builder()
                            .errorMessage(e.getMessage())
                            .build().toJson())
                    .build();
        }
    }
}
```

Interceptors are permitted to mutate the "interceptor context", which is a `Map<String, Object>`. Each interceptor in the chain, and the final handler, can access this context:

```java
public class IdentityInterceptor<Input> implements Interceptor<Input> {
    @Override
    public Response handle(ChainedRequestInput<Input> input) {
        input.getInterceptorContext().put("AuthenticatedUser", this.getAuthenticatedUser(input.getEvent()));
        return input.getChain().next(input);
    }
}
```

Interceptors can also mutate the response returned by the handler chain. An example use case might be adding cross-origin resource sharing headers:

```java
public static class AddCorsHeadersInterceptor<Input> implements Interceptor<Input> {
    @Override
    public Response handle(ChainedRequestInput<Input> input) {
        Response res = input.getChain().next(input);
        res.getHeaders().put("Access-Control-Allow-Origin", "*");
        res.getHeaders().put("Access-Control-Allow-Headers", "*");
        return res;
    }
}
```

##### Interceptors with Dependency Injection

Interceptors referenced by the `@Interceptors` annotation must be constructable with no arguments. If more complex instantiation of your interceptor is required (for example if you are using dependency injection or wish to pass configuration to your interceptor), you may instead override the `getInterceptors` method in your handler:

```java
public class SayHelloHandler extends SayHello {
    @Override
    public List<Interceptor<SayHelloInput>> getInterceptors() {
        return Arrays.asList(
                new MyConfiguredInterceptor<>(42),
                new MyOtherConfiguredInterceptor<>("configuration"));
    }

    @Override
    public SayHelloResponse handle(SayHelloRequestInput sayHelloRequestInput) {
        return SayHello200Response.of(HelloResponse.builder()
                .message(String.format("Hello %s!", sayHelloRequestInput.getInput().getRequestParameters().getName()))
                .build());
    }
}
```

### Libraries

Libraries are generated code projects which are not fully-fledged runtime languages.

#### TypeScript React Query Hooks

This library contains generated [react-query](https://tanstack.com/query/latest) hooks for interacting with your API from a React website. You can generate these by adding the following options to your `TypeSafeApiProject` in your `.projenrc`:

```python
# Example automatically generated from non-compiling source. May contain errors.
TypeSafeApiProject(
    library={
        "libraries": [Library.TYPESCRIPT_REACT_QUERY_HOOKS]
    }, ...
)
```

##### Usage in a React Website

First, make sure you create an instance of the API client (making sure to set the base URL and fetch instance). For example:

```python
# Example automatically generated from non-compiling source. May contain errors.
use_my_api_client = () =>
  useMemo(
    () =>
      new MyApi(
        new Configuration({
          basePath:
            "https://example123.execute-api.ap-southeast-2.amazonaws.com/prod",
          fetchApi: window.fetch.bind(window),
        })
      ),
    []
  )
```

Note that if you are using the [Cloudscape React Website](../cloudscape-react-ts-website/README.md) with [AWS NorthStar](https://aws.github.io/aws-northstar/) and IAM (Sigv4) Auth for your API, you can use NorthStar's [`useSigv4Client()` hook](https://aws.github.io/aws-northstar/?path=/story/components-cognitoauth-sigv4client-docs--page) to create
an instance of `fetch` which will sign requests with the logged in user's credentials. For example:

```python
# Example automatically generated from non-compiling source. May contain errors.
use_my_api_client = () => {
  const client = useSigv4Client();
  return useMemo(
    () =>
      client
        ? new MyApi(
            new Configuration({
              basePath:
                "https://example123.execute-api.ap-southeast-2.amazonaws.com/prod",
              fetchApi: client,
            })
          )
        : undefined,
    [client]
  );
}
```

Next, instantiate the client provider above where you would like to use the hooks in your component hierarchy (such as above your router). For example:

```tsx
import { DefaultApiClientProvider } from "myapi-typescript-react-query-hooks";

const api = useMyApiClient();

return api ? (
  <DefaultApiClientProvider apiClient={api}>
    {/* Components within the provider may make use of the hooks */}
  </DefaultApiClientProvider>
) : (
  <p>Loading...</p>
);
```

Finally, you can import and use your generated hooks. For example:

```tsx
export const MyComponent: FC<MyComponentProps> = () => {
  const sayHello = useSayHello({ name: "World" });

  return sayHello.isLoading ? (
    <p>Loading...</p>
  ) : sayHello.isError ? (
    <p>Error!</p>
  ) : (
    <h1>{sayHello.data.message}</h1>
  );
};
```

##### Paginated Operations

You can generate `useInfiniteQuery` hooks instead of `useQuery` hooks for paginated API operations, by making use of the vendor extension `x-paginated` in your operation in the OpenAPI specification. You must specify both the `inputToken` and `outputToken`, which indicate the properties from the input and output used for pagination. For example in OpenAPI:

```yaml
paths:
  /pets:
    get:
      x-paginated:
        # Input property with the token to request the next page
        inputToken: nextToken
        # Output property with the token to request the next page
        outputToken: nextToken
      parameters:
        - in: query
          name: nextToken
          schema:
            type: string
          required: true
      responses:
        200:
          description: Successful response
          content:
            application/json:
              schema:
                type: object
                properties:
                  nextToken:
                    type: string
```

In Smithy, until [custom vendor extensions can be rendered via traits](https://github.com/awslabs/smithy/pull/1609), you can add the `x-paginated` vendor extension via `smithyBuildOptions` in your `TypeSafeApiProject`, for example:

```python
# Example automatically generated from non-compiling source. May contain errors.
TypeSafeApiProject(
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                },
                "smithy_build_options": {
                    "projections": {
                        "openapi": {
                            "plugins": {
                                "openapi": {
                                    "json_add": {
                                        # Add the x-paginated vendor extension to the GET /pets operation
                                        "/paths/~1pets/get/x-paginated": {
                                            "input_token": "nextToken",
                                            "output_token": "nextToken"
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }, ...
)
```

### Quick Start: Python

This guide assumes you want to write your CDK infrastructure in Python and your lambda handlers in Python, however note that you your infrastructure language and lambda handler language(s) are not tied to one another, you can mix and match as you like. Just specify the language in `runtime.languages` for any language you would like to write lambda handlers in.

#### Create Your API Project

Use the project in your `.projenrc.ts`. It can either be part of an [`nx-monorepo`](../nx-monorepo/README.md) (recommended) or used in a standalone fashion.

```python
# Example automatically generated from non-compiling source. May contain errors.
from aws_prototyping_sdk.nx_monorepo import NxMonorepoProject
from aws_prototyping_sdk.type_safe_api import TypeSafeApiProject
from projen.awscdk import AwsCdkTypeScriptApp
from projen.python import PythonProject

# Create the monorepo
monorepo = NxMonorepoProject(
    name="monorepo",
    default_release_branch="main"
)

# Create the API project
api = TypeSafeApiProject(
    name="myapi",
    parent=monorepo,
    outdir="packages/api",
    # Smithy as the model language. You can also use ModelLanguage.OPENAPI
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                }
            }
        }
    },
    # Generate client and server types in TypeScript, Python, and Java
    runtime={
        "languages": [Language.TYPESCRIPT, Language.PYTHON, Language.JAVA]
    },
    # Generate CDK infrastructure in Python
    infrastructure={
        "language": Language.PYTHON
    },
    # Generate HTML documentation
    documentation={
        "formats": [DocumentationFormat.HTML_REDOC]
    }
)

# Create a project for our lambda handlers written in python
lambdas = PythonProject(
    name="lambdas",
    parent=monorepo,
    outdir="packages/lambdas",
    author_email="me@example.com",
    author_name="me",
    module_name="lambdas",
    version="1.0.0",
    # Poetry is used to simplify local python dependencies
    poetry=True
)

# Add a local dependency on the generated python runtime
monorepo.add_python_poetry_dependency(lambdas, api.runtime.python)

# Add commands to the lambda project's package task to create a distributable which can be deployed to AWS Lambda
lambdas.package_task.exec("mkdir -p lambda-dist && rm -rf lambda-dist/*")
lambdas.package_task.exec(f"cp -r {lambdas.moduleName} lambda-dist/{lambdas.moduleName}")
lambdas.package_task.exec("poetry export --without-hashes --format=requirements.txt > lambda-dist/requirements.txt")
lambdas.package_task.exec("pip install -r lambda-dist/requirements.txt --target lambda-dist --upgrade")
lambdas.gitignore.add_patterns("lambda-dist")

# Create a CDK infrastructure project
infra = AwsCdkPythonApp(
    name="infra",
    parent=monorepo,
    outdir="packages/infra",
    author_email="me@example.com",
    author_name="me",
    cdk_version="2.0.0",
    module_name="infra",
    version="1.0.0",
    poetry=True
)

# The infrastructure project depends on the python types, python infrastructure, and the lambda package
monorepo.add_python_poetry_dependency(infra, api.runtime.python)
monorepo.add_python_poetry_dependency(infra, api.infrastructure.python)
monorepo.add_python_poetry_dependency(infra, lambdas)

monorepo.synth()
```

#### Use the CDK Construct

In your CDK application, consume the `Api` construct, vended from the generated Python infrastructure package.

```python
import os
from aws_cdk import Stack
from constructs import Construct
from aws_cdk.aws_lambda import LayerVersion, Code, Function, Runtime
from aws_prototyping_sdk.type_safe_api import Authorizers, TypeSafeApiIntegration, Integrations

from myapi_python_runtime.apis.tags.default_api_operation_config import OperationConfig
from myapi_python_infra.api import Api
from pathlib import Path
from os import path

class MyStack(Stack):
    def __init__(self, scope: Construct, construct_id: str, **kwargs) -> None:
        super().__init__(scope, construct_id, **kwargs)

        # Use the generated Api construct
        self.api = Api(self, 'Api',
            default_authorizer=Authorizers.iam(),
            integrations=OperationConfig(
                say_hello=TypeSafeApiIntegration(
                    # Create a python lambda function from our "lambda-dist" package
                    integration=Integrations.lambda_(Function(self, 'SayHello',
                        runtime=Runtime.PYTHON_3_9,
                        code=Code.from_asset(path.join("..", "lambdas", "lambda-dist")),
                        handler="lambdas.say_hello.handler",
                    )),
                ),
            ),
        )
```

#### Implement a Lambda Handler

In your `lambdas` project you can define your lambda handler in its source directory, eg `lambdas/lambdas/say_hello.py`:

```python
from myapi_python_runtime.model.say_hello_response_content import SayHelloResponseContent
from myapi_python_runtime.apis.tags.default_api_operation_config import say_hello_handler,
    SayHelloRequest, SayHelloOperationResponses, ApiResponse


@say_hello_handler
def handler(input: SayHelloRequest, **kwargs) -> SayHelloOperationResponses:
    return ApiResponse(
        status_code=200,
        body=SayHelloResponseContent(message="Hello {}".format(input.request_parameters["name"])),
        headers={}
    )
```

### Quick Start: Java

This guide assumes you want to write your CDK infrastructure in Java and your lambda handlers in Java, however note that you your infrastructure language and lambda handler language(s) are not tied to one another, you can mix and match as you like.

#### Create Your API Project

Use the project in your `.projenrc.ts`. It can either be part of an [`nx-monorepo`](../nx-monorepo/README.md) (recommended) or used in a standalone fashion.

```python
# Example automatically generated from non-compiling source. May contain errors.
from projen.PluginExecution import PluginExecution
from aws_prototyping_sdk.nx_monorepo import NxMonorepoProject
from aws_prototyping_sdk.type_safe_api import TypeSafeApiProject
from projen.awscdk import AwsCdkTypeScriptApp
from projen.java import JavaProject

# Create the monorepo
monorepo = NxMonorepoProject(
    name="monorepo",
    default_release_branch="main"
)

# Create the API project
api = TypeSafeApiProject(
    name="myapi",
    parent=monorepo,
    outdir="packages/api",
    # Smithy as the model language. You can also use ModelLanguage.OPENAPI
    model={
        "language": ModelLanguage.SMITHY,
        "options": {
            "smithy": {
                "service_name": {
                    "namespace": "com.mycompany",
                    "service_name": "MyApi"
                }
            }
        }
    },
    # Generate client and server types in TypeScript, Python and Java
    runtime={
        "languages": [Language.TYPESCRIPT, Language.PYTHON, Language.JAVA]
    },
    # Generate CDK infrastructure in Java
    infrastructure={
        "language": Language.JAVA
    },
    # Generate HTML documentation
    documentation={
        "formats": [DocumentationFormat.HTML_REDOC]
    }
)

lambdas = JavaProject(
    name="lambdas",
    parent=monorepo,
    outdir="packages/lambdas",
    artifact_id="lambdas",
    group_id="com.my.api",
    version="1.0.0"
)

# The lambdas package needs a dependency on the generated java runtime
monorepo.add_java_dependency(lambdas, api.runtime.java)

# Use the maven shade plugin to build a "super jar" which we can deploy to AWS Lambda
lambdas.pom.add_plugin("org.apache.maven.plugins/maven-shade-plugin@3.3.0",
    configuration={
        "create_dependency_reduced_pom": False
    },
    executions=[PluginExecution(
        id="shade-task",
        phase="package",
        goals=["shade"]
    )
    ]
)

infra = AwsCdkJavaApp(
    name="infra",
    parent=monorepo,
    outdir="packages/infra",
    artifact_id="infra",
    group_id="com.my.api",
    main_class="com.my.api.MyApp",
    version="1.0.0",
    cdk_version="2.0.0"
)

# Add a dependency on the generated CDK infrastructure
monorepo.add_java_dependency(infra, api.infrastructure.java)

# Make sure the java lambda builds before our CDK infra
monorepo.add_implicit_dependency(infra, lambdas)

monorepo.synth()
```

#### Use the CDK Construct

In your CDK application, consume the `Api` construct, vended from the generated Java infrastructure package.

```java
package com.my.api;

import com.generated.api.myapijavainfra.infra.Api;
import com.generated.api.myapijavainfra.infra.ApiProps;
import com.generated.api.myapijavaruntime.runtime.api.OperationConfig;

import software.amazon.awscdk.Duration;
import software.amazon.awscdk.services.apigateway.CorsOptions;
import software.amazon.awscdk.services.lambda.Code;
import software.amazon.awscdk.services.lambda.Function;
import software.amazon.awscdk.services.lambda.FunctionProps;
import software.amazon.awscdk.services.lambda.Runtime;
import software.aws.awsprototypingsdk.typesafeapi.Authorizers;
import software.aws.awsprototypingsdk.typesafeapi.Integrations;
import software.aws.awsprototypingsdk.typesafeapi.TypeSafeApiIntegration;

import software.amazon.awscdk.App;
import software.amazon.awscdk.Stack;

import java.util.Arrays;

public class MyApp {
    public static void main(final String[] args) {
        App app = new App();
        Stack s = new Stack(app, "infra");

        // Declare the API construct to deploy the API Gateway resources
        new Api(s, "Api", ApiProps.builder()
                .defaultAuthorizer(Authorizers.iam())
                .corsOptions(CorsOptions.builder()
                        .allowOrigins(Arrays.asList("*"))
                        .allowMethods(Arrays.asList("*"))
                        .build())
                .integrations(OperationConfig.<TypeSafeApiIntegration>builder()
                        .sayHello(TypeSafeApiIntegration.builder()
                                .integration(Integrations.lambda(
                                        // Point the lambda function to our built jar from the "lambdas" package
                                        new Function(s, "say-hello", FunctionProps.builder()
                                                .code(Code.fromAsset("../lambdas/dist/java/com/my/api/lambdas/1.0.0/lambdas-1.0.0.jar"))
                                                .handler("com.my.api.SayHelloHandler")
                                                .runtime(Runtime.JAVA_11)
                                                .timeout(Duration.seconds(30))
                                                .build())))
                                .build())
                        .build())
                .build());

        app.synth();
    }
}
```

#### Implement a Lambda Handler

In your `lambdas` project you can define your lambda handler in its source directory, eg `lambdas/src/main/java/com/my/api/SayHelloHandler.java`:

```java
package com.my.api;

import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHello;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHello200Response;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHelloRequestInput;
import com.generated.api.myapijavaruntime.runtime.api.Handlers.SayHelloResponse;
import com.generated.api.myapijavaruntime.runtime.model.SayHelloResponseContent;

/**
 * An example lambda handler which uses the generated handler wrapper class (Handlers.SayHello) to manage marshalling
 * inputs and outputs.
 */
public class SayHelloHandler extends SayHello {
    @Override
    public SayHelloResponse handle(SayHelloRequestInput sayHelloRequestInput) {
        return SayHello200Response.of(SayHelloResponseContent.builder()
                .message(String.format("Hello %s", sayHelloRequestInput.getInput().getRequestParameters().getName()))
                .build());
    }
}

```

### Other Details

#### Customising Generated Types/Infrastructure Projects

By default, the generated types and infrastructure projects are configured automatically, including their project names. You can customise the generated projects using the `runtime.options.<language>` or `infrastructure.options.<language>` properties when constructing the `TypeSafeApiProject`.

#### AWS WAFv2 Web ACL

By default, a [Web ACL](https://docs.aws.amazon.com/waf/latest/developerguide/web-acl.html) is deployed and attached to your API Gateway Rest API with the "[AWSManagedRulesCommonRuleSet](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-baseline.html)", which provides protection against exploitation of a wide range of vulnerabilities, including some of the high risk and commonly occurring vulnerabilities described in OWASP publications such as [OWASP Top 10](https://owasp.org/www-project-top-ten/).

You can customise the Web ACL configuration via the `webAclOptions` of your `Api` CDK construct, eg:

```python
# Example automatically generated from non-compiling source. May contain errors.
class SampleApi(Api):
    def __init__(self, scope, id):
        super().__init__(scope, id,
            integrations={...},
            web_acl_options={
                # Allow access only to specific CIDR ranges
                "cidr_allow_list": {
                    "cidr_type": "IPV4",
                    "cidr_ranges": ["1.2.3.4/5"]
                },
                # Pick from the set here: https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-list.html
                "managed_rules": [{"vendor": "AWS", "name": "AWSManagedRulesSQLiRuleSet"}
                ]
            }
        )
```

You can remove the Web ACL entirely with `webAclOptions: { disable: true }` - you may wish to use this if you'd like to set up a Web ACL yourself with more control over the rules.

#### Smithy IntelliJ Plugin

The Smithy-based projects are compatible with the [Smithy IntelliJ Plugin](https://github.com/iancaffey/smithy-intellij-plugin), which provides syntax highlighting and auto-complete for your Smithy model. To make use of it, perform the following steps:

* Install the "Smithy" plugin (under `Preferences -> Plugins`)
* Right-click on the `smithy/build.gradle` file in your Smithy API project
* Select "Link Gradle Project"

#### Tagging Operations

Operations can be grouped together into logical collections via tags. This can be achieved in Smithy with the `@tags` trait:

```smithy
@tags(["pets", "users"])
operation PurchasePet {
  ...
}
```

Or in OpenAPI using the `tags` property:

```yaml
paths:
  /pets/purchase:
    post:
      operationId: purchasePet
      tags:
        - pets
        - users
      ...
```

When multiple tags are used, the "first" tag is considered to be the API that the operation belongs to, so in the generated client, the above example operation would be included in the `PetsApi` client but not the `UsersApi` client.

Multiple tags are still useful for documentation generation, for example `DocumentationFormat.HTML_REDOC` will group operations by tag in the side navigation bar.

If you would like to introduce tags without breaking existing clients, we recommend first adding a tag named `default` to all operations.

⚠️ **Important Note**: Smithy versions below `1.28.0` sort tags in alphabetical order and so the "first" tag will be the earliest in the alphabet. Therefore, if using tags with older versions of Smithy, we recommend prefixing your desired first tag with an underscore (for example `_default`). This is rectified in `1.28.0`, where tag order from the `@tags` trait is preserved.

#### Smithy Model Libraries and Dependencies

You can instantiate the TypeSafeApiModelProject on its own to create a standalone Smithy model library.

You can consume the library using the `addSmithyDeps` method, which adds a local file dependency on the built Smithy jar.

```python
# Example automatically generated from non-compiling source. May contain errors.
# Standalone model project, used as our model library
shapes = TypeSafeApiModelProject(
    name="shapes",
    parent=monorepo,
    outdir="packages/shapes",
    model_language=ModelLanguage.SMITHY,
    model_options={
        "smithy": {
            "service_name": {
                "namespace": "com.my.shared.shapes",
                "service_name": "Ignored"
            }
        }
    }
)

api = TypeSafeApiProject(...)

# Add the implicit monorepo dependency (if using the nx-monorepo) to ensure the shape library is built before the api model
monorepo.add_implicit_dependency(api.model, shapes)

# Add a local file dependency on the built shapes jar
api.model.smithy.add_smithy_deps(shapes.smithy)
```

#### Local API Development Server

You can use the [AWS SAM CLI](https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/install-sam-cli.html) to run a local development server for your API. You can achieve this using the following steps:

1. Synthesize your CDK stack containing your `Api` construct (this might be your `AwsCdkTypeScriptApp` project for example), with the context property `type-safe-api-local` set to `true`, for example:

```bash
cd packages/infra
npx cdk synth --context type-safe-api-local=true
```

1. Use the AWS SAM CLI to start the local development server, pointing it at the cloudformation template synthesized from the above command (note that the command will fail if docker is not running)

```bash
sam local start-api -t cdk.out/<your-stack>.template.json
```

You will need to repeat the above steps every time you make a code change for them to be reflected in your local development server.

See the [AWS SAM CLI Reference](https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/sam-cli-command-reference-sam-local-start-api.html) for more information on the commands to run.

Make sure you do not deploy your CDK stack with `type-safe-api-local` set to `true`, since this uses an inline API definition which bloats the CloudFormation template and can exceed the maximum template size depending on the size of your API.

##### Limitations

Note that there is currently a limitation with SAM CLI where it does not support mock integrations, which means that the development server will not respond to OPTIONS requests even if you specified `corsOptions: { ... }` in your `Api` construct. This is being tracked as a [feature request here](https://github.com/aws/aws-sam-cli/issues/4973).

Note also that your API business logic may include operations which do not work locally, or may interact with real AWS resources depending on the AWS credentials you start your local development server with.
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### TypeSafeRestApi <a name="TypeSafeRestApi" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi"></a>

A construct for creating an api gateway rest api based on the definition in the OpenAPI spec.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApi(
  scope: Construct,
  id: str,
  cloud_watch_role: bool = None,
  deploy: bool = None,
  deploy_options: StageOptions = None,
  description: str = None,
  disable_execute_api_endpoint: bool = None,
  domain_name: DomainNameOptions = None,
  endpoint_export_name: str = None,
  endpoint_types: typing.List[EndpointType] = None,
  fail_on_warnings: bool = None,
  parameters: typing.Mapping[str] = None,
  policy: PolicyDocument = None,
  rest_api_name: str = None,
  retain_deployments: bool = None,
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[MethodAndPath],
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None,
  spec_path: str,
  web_acl_options: TypeSafeApiWebAclOptions = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.id">id</a></code> | <code>str</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.cloudWatchRole">cloud_watch_role</a></code> | <code>bool</code> | Automatically configure an AWS CloudWatch role for API Gateway. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deploy">deploy</a></code> | <code>bool</code> | Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deployOptions">deploy_options</a></code> | <code>aws_cdk.aws_apigateway.StageOptions</code> | Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.description">description</a></code> | <code>str</code> | A description of the RestApi construct. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.disableExecuteApiEndpoint">disable_execute_api_endpoint</a></code> | <code>bool</code> | Specifies whether clients can invoke the API using the default execute-api endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.domainName">domain_name</a></code> | <code>aws_cdk.aws_apigateway.DomainNameOptions</code> | Configure a custom domain name and map it to this API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointExportName">endpoint_export_name</a></code> | <code>str</code> | Export name for the CfnOutput containing the API endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointTypes">endpoint_types</a></code> | <code>typing.List[aws_cdk.aws_apigateway.EndpointType]</code> | A list of the endpoint types of the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.failOnWarnings">fail_on_warnings</a></code> | <code>bool</code> | Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.parameters">parameters</a></code> | <code>typing.Mapping[str]</code> | Custom header parameters for the request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.policy">policy</a></code> | <code>aws_cdk.aws_iam.PolicyDocument</code> | A policy document that contains the permissions for this RestApi. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.restApiName">rest_api_name</a></code> | <code>str</code> | A name for the API Gateway RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.retainDeployments">retain_deployments</a></code> | <code>bool</code> | Retains old deployment resources when the API changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.specPath">spec_path</a></code> | <code>str</code> | Path to the JSON open api spec. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.webAclOptions">web_acl_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a></code> | Options for the AWS WAF v2 WebACL associated with the api. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.id"></a>

- *Type:* str

---

##### `cloud_watch_role`<sup>Optional</sup> <a name="cloud_watch_role" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.cloudWatchRole"></a>

- *Type:* bool
- *Default:* false if `@aws-cdk/aws-apigateway:disableCloudWatchRole` is enabled, true otherwise

Automatically configure an AWS CloudWatch role for API Gateway.

---

##### `deploy`<sup>Optional</sup> <a name="deploy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deploy"></a>

- *Type:* bool
- *Default:* true

Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes.

Since API Gateway deployments are immutable, When this option is enabled
(by default), an AWS::ApiGateway::Deployment resource will automatically
created with a logical ID that hashes the API model (methods, resources
and options). This means that when the model changes, the logical ID of
this CloudFormation resource will change, and a new deployment will be
created.

If this is set, `latestDeployment` will refer to the `Deployment` object
and `deploymentStage` will refer to a `Stage` that points to this
deployment. To customize the stage options, use the `deployOptions`
property.

A CloudFormation Output will also be defined with the root URL endpoint
of this REST API.

---

##### `deploy_options`<sup>Optional</sup> <a name="deploy_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.deployOptions"></a>

- *Type:* aws_cdk.aws_apigateway.StageOptions
- *Default:* Based on defaults of `StageOptions`.

Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled.

If `deploy` is disabled,
this value cannot be set.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.description"></a>

- *Type:* str
- *Default:* 'Automatically created by the RestApi construct'

A description of the RestApi construct.

---

##### `disable_execute_api_endpoint`<sup>Optional</sup> <a name="disable_execute_api_endpoint" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.disableExecuteApiEndpoint"></a>

- *Type:* bool
- *Default:* false

Specifies whether clients can invoke the API using the default execute-api endpoint.

To require that clients use a custom domain name to invoke the
API, disable the default endpoint.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html)

---

##### `domain_name`<sup>Optional</sup> <a name="domain_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.domainName"></a>

- *Type:* aws_cdk.aws_apigateway.DomainNameOptions
- *Default:* no domain name is defined, use `addDomainName` or directly define a `DomainName`.

Configure a custom domain name and map it to this API.

---

##### `endpoint_export_name`<sup>Optional</sup> <a name="endpoint_export_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointExportName"></a>

- *Type:* str
- *Default:* when no export name is given, output will be created without export

Export name for the CfnOutput containing the API endpoint.

---

##### `endpoint_types`<sup>Optional</sup> <a name="endpoint_types" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.endpointTypes"></a>

- *Type:* typing.List[aws_cdk.aws_apigateway.EndpointType]
- *Default:* EndpointType.EDGE

A list of the endpoint types of the API.

Use this property when creating
an API.

---

##### `fail_on_warnings`<sup>Optional</sup> <a name="fail_on_warnings" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.failOnWarnings"></a>

- *Type:* bool
- *Default:* false

Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.parameters"></a>

- *Type:* typing.Mapping[str]
- *Default:* No parameters.

Custom header parameters for the request.

> [https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html](https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html)

---

##### `policy`<sup>Optional</sup> <a name="policy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.policy"></a>

- *Type:* aws_cdk.aws_iam.PolicyDocument
- *Default:* No policy.

A policy document that contains the permissions for this RestApi.

---

##### `rest_api_name`<sup>Optional</sup> <a name="rest_api_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.restApiName"></a>

- *Type:* str
- *Default:* ID of the RestApi construct.

A name for the API Gateway RestApi resource.

---

##### `retain_deployments`<sup>Optional</sup> <a name="retain_deployments" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.retainDeployments"></a>

- *Type:* bool
- *Default:* false

Retains old deployment resources when the API changes.

This allows
manually reverting stages to point to old deployments via the AWS
Console.

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.integrations"></a>

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.operationLookup"></a>

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]

Details about each operation.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.corsOptions"></a>

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.defaultAuthorizer"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

##### `spec_path`<sup>Required</sup> <a name="spec_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.specPath"></a>

- *Type:* str

Path to the JSON open api spec.

---

##### `web_acl_options`<sup>Optional</sup> <a name="web_acl_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.Initializer.parameter.webAclOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a>

Options for the AWS WAF v2 WebACL associated with the api.

By default, a Web ACL with the AWS default managed
rule set will be associated with the API. These options may disable or override the defaults.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.toString">to_string</a></code> | Returns a string representation of this construct. |

---

##### `to_string` <a name="to_string" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.toString"></a>

```python
def to_string() -> str
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct">is_construct</a></code> | Checks if `x` is a construct. |

---

##### `is_construct` <a name="is_construct" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApi.is_construct(
  x: typing.Any
)
```

Checks if `x` is a construct.

Use this method instead of `instanceof` to properly detect `Construct`
instances, even when the construct library is symlinked.

Explanation: in JavaScript, multiple copies of the `constructs` library on
disk are seen as independent, completely different libraries. As a
consequence, the class `Construct` in each copy of the `constructs` library
is seen as a different class, and an instance of one class will not test as
`instanceof` the other class. `npm install` will not create installations
like this, but users may manually symlink construct libraries together or
use a monorepo tool: in those cases, multiple copies of the `constructs`
library can be accidentally installed, and `instanceof` will behave
unpredictably. It is safest to avoid using `instanceof`, and using
this type-testing method instead.

###### `x`<sup>Required</sup> <a name="x" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.isConstruct.parameter.x"></a>

- *Type:* typing.Any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.api">api</a></code> | <code>aws_cdk.aws_apigateway.SpecRestApi</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.ipSet">ip_set</a></code> | <code>aws_cdk.aws_wafv2.CfnIPSet</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAcl">web_acl</a></code> | <code>aws_cdk.aws_wafv2.CfnWebACL</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAclAssociation">web_acl_association</a></code> | <code>aws_cdk.aws_wafv2.CfnWebACLAssociation</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.node"></a>

```python
node: Node
```

- *Type:* constructs.Node

The tree node.

---

##### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.api"></a>

```python
api: SpecRestApi
```

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

---

##### `ip_set`<sup>Optional</sup> <a name="ip_set" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.ipSet"></a>

```python
ip_set: CfnIPSet
```

- *Type:* aws_cdk.aws_wafv2.CfnIPSet

---

##### `web_acl`<sup>Optional</sup> <a name="web_acl" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAcl"></a>

```python
web_acl: CfnWebACL
```

- *Type:* aws_cdk.aws_wafv2.CfnWebACL

---

##### `web_acl_association`<sup>Optional</sup> <a name="web_acl_association" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApi.property.webAclAssociation"></a>

```python
web_acl_association: CfnWebACLAssociation
```

- *Type:* aws_cdk.aws_wafv2.CfnWebACLAssociation

---


## Structs <a name="Structs" id="Structs"></a>

### ApiGatewayIntegration <a name="ApiGatewayIntegration" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration"></a>

Represents an api gateway integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegration(
  cache_key_parameters: typing.List[str] = None,
  cache_namespace: str = None,
  connection_id: str = None,
  connection_type: str = None,
  content_handling: str = None,
  credentials: str = None,
  http_method: str = None,
  passthrough_behavior: str = None,
  request_parameters: typing.Mapping[str] = None,
  request_templates: typing.Mapping[str] = None,
  responses: typing.Mapping[ApiGatewayIntegrationResponse] = None,
  timeout_in_millis: typing.Union[int, float] = None,
  tls_config: ApiGatewayIntegrationTlsConfig = None,
  type: str = None,
  uri: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheKeyParameters">cache_key_parameters</a></code> | <code>typing.List[str]</code> | A list of request parameters whose values are to be cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheNamespace">cache_namespace</a></code> | <code>str</code> | An API-specific tag group of related cached parameters. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionId">connection_id</a></code> | <code>str</code> | The ID of a VpcLink for the private integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionType">connection_type</a></code> | <code>str</code> | The integration connection type. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.contentHandling">content_handling</a></code> | <code>str</code> | Request payload encoding conversion types. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.credentials">credentials</a></code> | <code>str</code> | For AWS IAM role-based credentials, specify the ARN of an appropriate IAM role. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.httpMethod">http_method</a></code> | <code>str</code> | The HTTP method used in the integration request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.passthroughBehavior">passthrough_behavior</a></code> | <code>str</code> | Specifies how a request payload of unmapped content type is passed through the integration request without modification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestParameters">request_parameters</a></code> | <code>typing.Mapping[str]</code> | Specifies mappings from method request parameters to integration request parameters. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestTemplates">request_templates</a></code> | <code>typing.Mapping[str]</code> | Mapping templates for a request payload of specified MIME types. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.responses">responses</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse">ApiGatewayIntegrationResponse</a>]</code> | Defines the method's responses and specifies desired parameter mappings or payload mappings from integration responses to method responses. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.timeoutInMillis">timeout_in_millis</a></code> | <code>typing.Union[int, float]</code> | Custom timeout between 50 and 29,000 milliseconds. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.tlsConfig">tls_config</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig">ApiGatewayIntegrationTlsConfig</a></code> | Specifies the TLS configuration for an integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.type">type</a></code> | <code>str</code> | The type of integration with the specified backend. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.uri">uri</a></code> | <code>str</code> | The endpoint URI of the backend. |

---

##### `cache_key_parameters`<sup>Optional</sup> <a name="cache_key_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheKeyParameters"></a>

```python
cache_key_parameters: typing.List[str]
```

- *Type:* typing.List[str]

A list of request parameters whose values are to be cached.

---

##### `cache_namespace`<sup>Optional</sup> <a name="cache_namespace" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.cacheNamespace"></a>

```python
cache_namespace: str
```

- *Type:* str

An API-specific tag group of related cached parameters.

---

##### `connection_id`<sup>Optional</sup> <a name="connection_id" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionId"></a>

```python
connection_id: str
```

- *Type:* str

The ID of a VpcLink for the private integration.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_VpcLink.html](https://docs.aws.amazon.com/apigateway/latest/api/API_VpcLink.html)

---

##### `connection_type`<sup>Optional</sup> <a name="connection_type" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.connectionType"></a>

```python
connection_type: str
```

- *Type:* str

The integration connection type.

The valid value is "VPC_LINK" for private integration or "INTERNET", otherwise.

---

##### `content_handling`<sup>Optional</sup> <a name="content_handling" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.contentHandling"></a>

```python
content_handling: str
```

- *Type:* str

Request payload encoding conversion types.

Valid values are 1) CONVERT_TO_TEXT, for converting a binary payload
into a base64-encoded string or converting a text payload into a utf-8-encoded string or passing through the text
payload natively without modification, and 2) CONVERT_TO_BINARY, for converting a text payload into a
base64-decoded blob or passing through a binary payload natively without modification.

---

##### `credentials`<sup>Optional</sup> <a name="credentials" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.credentials"></a>

```python
credentials: str
```

- *Type:* str

For AWS IAM role-based credentials, specify the ARN of an appropriate IAM role.

If unspecified, credentials default
to resource-based permissions that must be added manually to allow the API to access the resource. For more
information, see Granting Permissions Using a Resource Policy.

Note: When using IAM credentials, make sure that AWS STS Regional endpoints are enabled for the Region where this
API is deployed for best performance.

---

##### `http_method`<sup>Optional</sup> <a name="http_method" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.httpMethod"></a>

```python
http_method: str
```

- *Type:* str

The HTTP method used in the integration request.

For Lambda function invocations, the value must be POST.

---

##### `passthrough_behavior`<sup>Optional</sup> <a name="passthrough_behavior" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.passthroughBehavior"></a>

```python
passthrough_behavior: str
```

- *Type:* str

Specifies how a request payload of unmapped content type is passed through the integration request without modification.

Supported values are when_no_templates, when_no_match, and never.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#passthroughBehavior](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#passthroughBehavior)

---

##### `request_parameters`<sup>Optional</sup> <a name="request_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestParameters"></a>

```python
request_parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies mappings from method request parameters to integration request parameters.

Supported request parameters
are querystring, path, header, and body.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestParameters.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestParameters.html)

---

##### `request_templates`<sup>Optional</sup> <a name="request_templates" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.requestTemplates"></a>

```python
request_templates: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Mapping templates for a request payload of specified MIME types.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestTemplates.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-requestTemplates.html)

---

##### `responses`<sup>Optional</sup> <a name="responses" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.responses"></a>

```python
responses: typing.Mapping[ApiGatewayIntegrationResponse]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse">ApiGatewayIntegrationResponse</a>]

Defines the method's responses and specifies desired parameter mappings or payload mappings from integration responses to method responses.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-responses.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-swagger-extensions-integration-responses.html)

---

##### `timeout_in_millis`<sup>Optional</sup> <a name="timeout_in_millis" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.timeoutInMillis"></a>

```python
timeout_in_millis: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

Custom timeout between 50 and 29,000 milliseconds.

The default value is 29,000 milliseconds or 29 seconds.

---

##### `tls_config`<sup>Optional</sup> <a name="tls_config" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.tlsConfig"></a>

```python
tls_config: ApiGatewayIntegrationTlsConfig
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig">ApiGatewayIntegrationTlsConfig</a>

Specifies the TLS configuration for an integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.type"></a>

```python
type: str
```

- *Type:* str

The type of integration with the specified backend.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#type](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html#type)

---

##### `uri`<sup>Optional</sup> <a name="uri" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegration.property.uri"></a>

```python
uri: str
```

- *Type:* str

The endpoint URI of the backend.

For integrations of the aws type, this is an ARN value.
For the HTTP integration, this is the URL of the HTTP endpoint including the https or http scheme.

---

### ApiGatewayIntegrationResponse <a name="ApiGatewayIntegrationResponse" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse"></a>

API Gateway integration response.

> [https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html](https://docs.aws.amazon.com/apigateway/latest/api/API_Integration.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegrationResponse(
  response_parameters: typing.Mapping[str],
  response_templates: typing.Mapping[str],
  status_code: str,
  content_handling: str = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseParameters">response_parameters</a></code> | <code>typing.Mapping[str]</code> | Specifies parameter mappings for the response. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseTemplates">response_templates</a></code> | <code>typing.Mapping[str]</code> | Specifies MIME type-specific mapping templates for the response’s payload. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.statusCode">status_code</a></code> | <code>str</code> | HTTP status code for the method response. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.contentHandling">content_handling</a></code> | <code>str</code> | Response payload encoding conversion types. |

---

##### `response_parameters`<sup>Required</sup> <a name="response_parameters" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseParameters"></a>

```python
response_parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies parameter mappings for the response.

---

##### `response_templates`<sup>Required</sup> <a name="response_templates" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.responseTemplates"></a>

```python
response_templates: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]

Specifies MIME type-specific mapping templates for the response’s payload.

---

##### `status_code`<sup>Required</sup> <a name="status_code" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.statusCode"></a>

```python
status_code: str
```

- *Type:* str

HTTP status code for the method response.

---

##### `content_handling`<sup>Optional</sup> <a name="content_handling" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationResponse.property.contentHandling"></a>

```python
content_handling: str
```

- *Type:* str

Response payload encoding conversion types.

Valid values are 1) CONVERT_TO_TEXT, for converting a binary payload
into a base64-encoded string or converting a text payload into a utf-8-encoded string or passing through the text
payload natively without modification, and 2) CONVERT_TO_BINARY, for converting a text payload into a
base64-decoded blob or passing through a binary payload natively without modification.

---

### ApiGatewayIntegrationTlsConfig <a name="ApiGatewayIntegrationTlsConfig" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig"></a>

Specifies the TLS configuration for an integration.

> [https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-extensions-integration-tls-config.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ApiGatewayIntegrationTlsConfig(
  insecure_skip_verification: bool = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.property.insecureSkipVerification">insecure_skip_verification</a></code> | <code>bool</code> | Specifies whether or not API Gateway skips verification that the certificate for an integration endpoint is issued by a supported certificate authority. |

---

##### `insecure_skip_verification`<sup>Optional</sup> <a name="insecure_skip_verification" id="@aws-prototyping-sdk/type-safe-api.ApiGatewayIntegrationTlsConfig.property.insecureSkipVerification"></a>

```python
insecure_skip_verification: bool
```

- *Type:* bool

Specifies whether or not API Gateway skips verification that the certificate for an integration endpoint is issued by a supported certificate authority.

This isn’t recommended, but it enables you to use certificates that are
signed by private certificate authorities, or certificates that are self-signed. If enabled, API Gateway still
performs basic certificate validation, which includes checking the certificate's expiration date, hostname, and
presence of a root certificate authority. Supported only for HTTP and HTTP_PROXY integrations.

---

### AuthorizerProps <a name="AuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps"></a>

Properties for an authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.AuthorizerProps(
  authorization_type: AuthorizationType,
  authorizer_id: str,
  authorization_scopes: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.AuthorizerProps.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

### CidrAllowList <a name="CidrAllowList" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList"></a>

Representation of a CIDR range.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CidrAllowList(
  cidr_ranges: typing.List[str],
  cidr_type: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrRanges">cidr_ranges</a></code> | <code>typing.List[str]</code> | Specify an IPv4 address by using CIDR notation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrType">cidr_type</a></code> | <code>str</code> | Type of CIDR range. |

---

##### `cidr_ranges`<sup>Required</sup> <a name="cidr_ranges" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrRanges"></a>

```python
cidr_ranges: typing.List[str]
```

- *Type:* typing.List[str]

Specify an IPv4 address by using CIDR notation.

For example:
To configure AWS WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify 192.0.2.44/32 .
To configure AWS WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24 .

For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing .

Specify an IPv6 address by using CIDR notation. For example:
To configure AWS WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128 .
To configure AWS WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64 .

---

##### `cidr_type`<sup>Required</sup> <a name="cidr_type" id="@aws-prototyping-sdk/type-safe-api.CidrAllowList.property.cidrType"></a>

```python
cidr_type: str
```

- *Type:* str

Type of CIDR range.

---

### CognitoAuthorizerProps <a name="CognitoAuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps"></a>

Properties used to configure a cognito authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CognitoAuthorizerProps(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | A list of authorization scopes configured on the method. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

Unique identifier for this authorizer.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.userPools"></a>

```python
user_pools: typing.List[IUserPool]
```

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizerProps.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

### CustomAuthorizerProps <a name="CustomAuthorizerProps" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps"></a>

Properties used to configure a custom authorizer.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CustomAuthorizerProps(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

Unique identifier for this authorizer.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.function"></a>

```python
function: IFunction
```

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.authorizerResultTtlInSeconds"></a>

```python
authorizer_result_ttl_in_seconds: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

##### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.identitySource"></a>

```python
identity_source: str
```

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerProps.property.type"></a>

```python
type: CustomAuthorizerType
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---

### DocumentationConfiguration <a name="DocumentationConfiguration" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration"></a>

Configuration for generated documentation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.DocumentationConfiguration(
  formats: typing.List[DocumentationFormat]
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.formats">formats</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat">DocumentationFormat</a>]</code> | Formats for generated documentation. |

---

##### `formats`<sup>Required</sup> <a name="formats" id="@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration.property.formats"></a>

```python
formats: typing.List[DocumentationFormat]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat">DocumentationFormat</a>]

Formats for generated documentation.

---

### GeneratedCodeOptions <a name="GeneratedCodeOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions"></a>

Options for generated clients.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedCodeOptions(
  java: JavaProjectOptions = None,
  python: PythonProjectOptions = None,
  typescript: TypeScriptProjectOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.java">java</a></code> | <code>projen.java.JavaProjectOptions</code> | Options for a generated java project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.python">python</a></code> | <code>projen.python.PythonProjectOptions</code> | Options for a generated python project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.typescript">typescript</a></code> | <code>projen.typescript.TypeScriptProjectOptions</code> | Options for a generated typescript project. |

---

##### `java`<sup>Optional</sup> <a name="java" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.java"></a>

```python
java: JavaProjectOptions
```

- *Type:* projen.java.JavaProjectOptions

Options for a generated java project.

These override the default inferred options.

---

##### `python`<sup>Optional</sup> <a name="python" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.python"></a>

```python
python: PythonProjectOptions
```

- *Type:* projen.python.PythonProjectOptions

Options for a generated python project.

These override the default inferred options.

---

##### `typescript`<sup>Optional</sup> <a name="typescript" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions.property.typescript"></a>

```python
typescript: TypeScriptProjectOptions
```

- *Type:* projen.typescript.TypeScriptProjectOptions

Options for a generated typescript project.

These override the default inferred options.

---

### GeneratedCodeProjects <a name="GeneratedCodeProjects" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects"></a>

Generated code projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedCodeProjects(
  java: JavaProject = None,
  python: PythonProject = None,
  typescript: TypeScriptProject = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.java">java</a></code> | <code>projen.java.JavaProject</code> | Generated java project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.python">python</a></code> | <code>projen.python.PythonProject</code> | Generated python project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.typescript">typescript</a></code> | <code>projen.typescript.TypeScriptProject</code> | Generated typescript project. |

---

##### `java`<sup>Optional</sup> <a name="java" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.java"></a>

```python
java: JavaProject
```

- *Type:* projen.java.JavaProject

Generated java project.

---

##### `python`<sup>Optional</sup> <a name="python" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.python"></a>

```python
python: PythonProject
```

- *Type:* projen.python.PythonProject

Generated python project.

---

##### `typescript`<sup>Optional</sup> <a name="typescript" id="@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects.property.typescript"></a>

```python
typescript: TypeScriptProject
```

- *Type:* projen.typescript.TypeScriptProject

Generated typescript project.

---

### GeneratedLibraryOptions <a name="GeneratedLibraryOptions" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions"></a>

Options for generated libraries.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedLibraryOptions(
  typescript_react_query_hooks: TypeScriptProjectOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.property.typescriptReactQueryHooks">typescript_react_query_hooks</a></code> | <code>projen.typescript.TypeScriptProjectOptions</code> | Options for the generated typescript react-query hooks library. |

---

##### `typescript_react_query_hooks`<sup>Optional</sup> <a name="typescript_react_query_hooks" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions.property.typescriptReactQueryHooks"></a>

```python
typescript_react_query_hooks: TypeScriptProjectOptions
```

- *Type:* projen.typescript.TypeScriptProjectOptions

Options for the generated typescript react-query hooks library.

These override the default inferred options.

---

### GeneratedLibraryProjects <a name="GeneratedLibraryProjects" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects"></a>

Generated library projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.GeneratedLibraryProjects(
  typescript_react_query_hooks: TypeScriptProject = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.property.typescriptReactQueryHooks">typescript_react_query_hooks</a></code> | <code>projen.typescript.TypeScriptProject</code> | Generated typescript react-query hooks project. |

---

##### `typescript_react_query_hooks`<sup>Optional</sup> <a name="typescript_react_query_hooks" id="@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects.property.typescriptReactQueryHooks"></a>

```python
typescript_react_query_hooks: TypeScriptProject
```

- *Type:* projen.typescript.TypeScriptProject

Generated typescript react-query hooks project.

---

### InfrastructureConfiguration <a name="InfrastructureConfiguration" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration"></a>

Configuration for generated infrastructure.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.InfrastructureConfiguration(
  language: Language,
  options: GeneratedCodeOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.language">language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a></code> | The language to generate the type-safe CDK infrastructure in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions">GeneratedCodeOptions</a></code> | Options for the infrastructure package. |

---

##### `language`<sup>Required</sup> <a name="language" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.language"></a>

```python
language: Language
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>

The language to generate the type-safe CDK infrastructure in.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration.property.options"></a>

```python
options: GeneratedCodeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions">GeneratedCodeOptions</a>

Options for the infrastructure package.

Note that only those provided for the specified language will apply.

---

### IntegrationGrantProps <a name="IntegrationGrantProps" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps"></a>

Properties for granting the API access to invoke the operation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IntegrationGrantProps(
  method: str,
  path: str,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.api">api</a></code> | <code>aws_cdk.aws_apigateway.SpecRestApi</code> | The api to grant permissions for. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.operationId">operation_id</a></code> | <code>str</code> | The ID of the operation for which permissions are being granted. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which permission resources can be created. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

##### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.api"></a>

```python
api: SpecRestApi
```

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

##### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.operationId"></a>

```python
operation_id: str
```

- *Type:* str

The ID of the operation for which permissions are being granted.

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.IntegrationGrantProps.property.scope"></a>

```python
scope: Construct
```

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

### IntegrationRenderProps <a name="IntegrationRenderProps" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps"></a>

Properties for rendering an integration into an API Gateway OpenAPI extension.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IntegrationRenderProps(
  method: str,
  path: str,
  operation_id: str,
  scope: Construct
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.operationId">operation_id</a></code> | <code>str</code> | The ID of the operation being rendered. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which the integration is being rendered. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

##### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.operationId"></a>

```python
operation_id: str
```

- *Type:* str

The ID of the operation being rendered.

---

##### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.IntegrationRenderProps.property.scope"></a>

```python
scope: Construct
```

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---

### LibraryConfiguration <a name="LibraryConfiguration" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration"></a>

Configuration for generated libraries.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.LibraryConfiguration(
  libraries: typing.List[Library],
  options: GeneratedLibraryOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.libraries">libraries</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Library">Library</a>]</code> | The library to generate. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions">GeneratedLibraryOptions</a></code> | Options for the generated library package. |

---

##### `libraries`<sup>Required</sup> <a name="libraries" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.libraries"></a>

```python
libraries: typing.List[Library]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Library">Library</a>]

The library to generate.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.LibraryConfiguration.property.options"></a>

```python
options: GeneratedLibraryOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryOptions">GeneratedLibraryOptions</a>

Options for the generated library package.

Note that only options for the specified libraries will apply

---

### ManagedRule <a name="ManagedRule" id="@aws-prototyping-sdk/type-safe-api.ManagedRule"></a>

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ManagedRule(
  name: str,
  vendor: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule.property.name">name</a></code> | <code>str</code> | The name of the managed rule group. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule.property.vendor">vendor</a></code> | <code>str</code> | The name of the managed rule group vendor. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.property.name"></a>

```python
name: str
```

- *Type:* str

The name of the managed rule group.

You use this, along with the vendor name, to identify the rule group.

---

##### `vendor`<sup>Required</sup> <a name="vendor" id="@aws-prototyping-sdk/type-safe-api.ManagedRule.property.vendor"></a>

```python
vendor: str
```

- *Type:* str

The name of the managed rule group vendor.

You use this, along with the rule group name, to identify the rule group.

---

### MethodAndPath <a name="MethodAndPath" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath"></a>

Structure to contain an API operation's method and path.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.MethodAndPath(
  method: str,
  path: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.method">method</a></code> | <code>str</code> | The http method of this operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.path">path</a></code> | <code>str</code> | The path of this operation in the api. |

---

##### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.method"></a>

```python
method: str
```

- *Type:* str

The http method of this operation.

---

##### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.MethodAndPath.property.path"></a>

```python
path: str
```

- *Type:* str

The path of this operation in the api.

---

### ModelConfiguration <a name="ModelConfiguration" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration"></a>

Configuration for modelling the API.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ModelConfiguration(
  language: ModelLanguage,
  options: ModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.language">language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | The language the API model is defined in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | Options for the API model. |

---

##### `language`<sup>Required</sup> <a name="language" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.language"></a>

```python
language: ModelLanguage
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

The language the API model is defined in.

---

##### `options`<sup>Required</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.ModelConfiguration.property.options"></a>

```python
options: ModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

Options for the API model.

---

### ModelOptions <a name="ModelOptions" id="@aws-prototyping-sdk/type-safe-api.ModelOptions"></a>

Options for models.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.ModelOptions(
  openapi: OpenApiModelOptions = None,
  smithy: SmithyModelOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions.property.openapi">openapi</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the OpenAPI model - required when model language is OPENAPI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions.property.smithy">smithy</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Options for the Smithy model - required when model language is SMITHY. |

---

##### `openapi`<sup>Optional</sup> <a name="openapi" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.property.openapi"></a>

```python
openapi: OpenApiModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the OpenAPI model - required when model language is OPENAPI.

---

##### `smithy`<sup>Optional</sup> <a name="smithy" id="@aws-prototyping-sdk/type-safe-api.ModelOptions.property.smithy"></a>

```python
smithy: SmithyModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Options for the Smithy model - required when model language is SMITHY.

---

### OpenApiDefinitionOptions <a name="OpenApiDefinitionOptions" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions"></a>

Options for the OpenAPI Spec.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiDefinitionOptions(
  open_api_options: OpenApiModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.property.openApiOptions">open_api_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the openapi model. |

---

##### `open_api_options`<sup>Required</sup> <a name="open_api_options" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinitionOptions.property.openApiOptions"></a>

```python
open_api_options: OpenApiModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the openapi model.

---

### OpenApiModelOptions <a name="OpenApiModelOptions" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions"></a>

Options for the OpenAPI model.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiModelOptions(
  title: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.property.title">title</a></code> | <code>str</code> | The title in the OpenAPI specification. |

---

##### `title`<sup>Required</sup> <a name="title" id="@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions.property.title"></a>

```python
title: str
```

- *Type:* str

The title in the OpenAPI specification.

---

### RuntimeConfiguration <a name="RuntimeConfiguration" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration"></a>

Configuration for generated runtime projects.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.RuntimeConfiguration(
  languages: typing.List[Language],
  options: GeneratedCodeOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.languages">languages</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>]</code> | The languages that runtime projects will be generated in. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.options">options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions">GeneratedCodeOptions</a></code> | Options for the generated runtimes. |

---

##### `languages`<sup>Required</sup> <a name="languages" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.languages"></a>

```python
languages: typing.List[Language]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.Language">Language</a>]

The languages that runtime projects will be generated in.

These projects can be used to provide type safety for
both client and server projects.

---

##### `options`<sup>Optional</sup> <a name="options" id="@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration.property.options"></a>

```python
options: GeneratedCodeOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeOptions">GeneratedCodeOptions</a>

Options for the generated runtimes.

Note that only options provided for the specified languages will apply.

---

### SmithyBuildOptions <a name="SmithyBuildOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions"></a>

Options for the smithy build files.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyBuildOptions(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None,
  ignore_missing_plugins: bool = None,
  maven: SmithyMavenConfiguration = None,
  projections: typing.Mapping[SmithyProjection] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.ignoreMissingPlugins">ignore_missing_plugins</a></code> | <code>bool</code> | If a plugin can't be found, Smithy will by default fail the build. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.maven">maven</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration">SmithyMavenConfiguration</a></code> | Maven configuration for the Smithy build project, used to specify dependencies and repositories in the build.gradle and smithy-build.json files. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.projections">projections</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection">SmithyProjection</a>]</code> | Map of projections name to projection configurations https://awslabs.github.io/smithy/2.0/guides/building-models/build-config.html#projections. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

##### `ignore_missing_plugins`<sup>Optional</sup> <a name="ignore_missing_plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.ignoreMissingPlugins"></a>

```python
ignore_missing_plugins: bool
```

- *Type:* bool
- *Default:* no ignoreMissingPlugins set in the smithy-build.json file

If a plugin can't be found, Smithy will by default fail the build.

This setting can be set to true to allow the build to progress
even if a plugin can't be found on the classpath.

---

##### `maven`<sup>Optional</sup> <a name="maven" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.maven"></a>

```python
maven: SmithyMavenConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration">SmithyMavenConfiguration</a>
- *Default:* the default configuration required for Smithy to OpenAPI conversion

Maven configuration for the Smithy build project, used to specify dependencies and repositories in the build.gradle and smithy-build.json files.

---

##### `projections`<sup>Optional</sup> <a name="projections" id="@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions.property.projections"></a>

```python
projections: typing.Mapping[SmithyProjection]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection">SmithyProjection</a>]
- *Default:* no projections

Map of projections name to projection configurations https://awslabs.github.io/smithy/2.0/guides/building-models/build-config.html#projections.

---

### SmithyCommon <a name="SmithyCommon" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon"></a>

Properties common to smithy plugins and the root smithy build.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyCommon(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyCommon.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

### SmithyDefinitionOptions <a name="SmithyDefinitionOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions"></a>

Options for a smithy build project.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyDefinitionOptions(
  smithy_options: SmithyModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.property.smithyOptions">smithy_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Smithy engine options. |

---

##### `smithy_options`<sup>Required</sup> <a name="smithy_options" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinitionOptions.property.smithyOptions"></a>

```python
smithy_options: SmithyModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Smithy engine options.

---

### SmithyMavenConfiguration <a name="SmithyMavenConfiguration" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration"></a>

Configuration for smithy maven dependencies.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyMavenConfiguration(
  dependencies: typing.List[str] = None,
  repository_urls: typing.List[str] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.dependencies">dependencies</a></code> | <code>typing.List[str]</code> | The dependencies used in the build.gradle and smithy-build.json files eg. software.amazon.smithy:smithy-validation-model:1.27.2 The following required dependencies are always added: - software.amazon.smithy:smithy-cli:1.27.2 - software.amazon.smithy:smithy-model:1.27.2 - software.amazon.smithy:smithy-openapi:1.27.2 - software.amazon.smithy:smithy-aws-traits:1.27.2 You can however override the version of these dependencies if required. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.repositoryUrls">repository_urls</a></code> | <code>typing.List[str]</code> | The repository urls used in the build.gradle and smithy-build.json files. |

---

##### `dependencies`<sup>Optional</sup> <a name="dependencies" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.dependencies"></a>

```python
dependencies: typing.List[str]
```

- *Type:* typing.List[str]

The dependencies used in the build.gradle and smithy-build.json files eg. software.amazon.smithy:smithy-validation-model:1.27.2 The following required dependencies are always added: - software.amazon.smithy:smithy-cli:1.27.2 - software.amazon.smithy:smithy-model:1.27.2 - software.amazon.smithy:smithy-openapi:1.27.2 - software.amazon.smithy:smithy-aws-traits:1.27.2 You can however override the version of these dependencies if required.

---

##### `repository_urls`<sup>Optional</sup> <a name="repository_urls" id="@aws-prototyping-sdk/type-safe-api.SmithyMavenConfiguration.property.repositoryUrls"></a>

```python
repository_urls: typing.List[str]
```

- *Type:* typing.List[str]
- *Default:* maven central and maven local

The repository urls used in the build.gradle and smithy-build.json files.

---

### SmithyModelOptions <a name="SmithyModelOptions" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions"></a>

Options for a Smithy model.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyModelOptions(
  service_name: SmithyServiceName,
  ignore_gradle_wrapper: bool = None,
  ignore_smithy_build_output: bool = None,
  smithy_build_options: SmithyBuildOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.serviceName">service_name</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName">SmithyServiceName</a></code> | Smithy service name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreGradleWrapper">ignore_gradle_wrapper</a></code> | <code>bool</code> | Set to false if you would like to check in your gradle wrapper. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreSmithyBuildOutput">ignore_smithy_build_output</a></code> | <code>bool</code> | Set to false if you would like to check in your smithy build output or have more fine-grained control over what is checked in, eg if you add other projections to the smithy-build.json file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.smithyBuildOptions">smithy_build_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions">SmithyBuildOptions</a></code> | Smithy build options. |

---

##### `service_name`<sup>Required</sup> <a name="service_name" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.serviceName"></a>

```python
service_name: SmithyServiceName
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName">SmithyServiceName</a>

Smithy service name.

---

##### `ignore_gradle_wrapper`<sup>Optional</sup> <a name="ignore_gradle_wrapper" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreGradleWrapper"></a>

```python
ignore_gradle_wrapper: bool
```

- *Type:* bool
- *Default:* true

Set to false if you would like to check in your gradle wrapper.

Do so if you would like to use a different version
of gradle to the one provided by default

---

##### `ignore_smithy_build_output`<sup>Optional</sup> <a name="ignore_smithy_build_output" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.ignoreSmithyBuildOutput"></a>

```python
ignore_smithy_build_output: bool
```

- *Type:* bool
- *Default:* true

Set to false if you would like to check in your smithy build output or have more fine-grained control over what is checked in, eg if you add other projections to the smithy-build.json file.

---

##### `smithy_build_options`<sup>Optional</sup> <a name="smithy_build_options" id="@aws-prototyping-sdk/type-safe-api.SmithyModelOptions.property.smithyBuildOptions"></a>

```python
smithy_build_options: SmithyBuildOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyBuildOptions">SmithyBuildOptions</a>

Smithy build options.

---

### SmithyProjection <a name="SmithyProjection" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection"></a>

A smithy build projection.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyProjection(
  imports: typing.List[str] = None,
  plugins: typing.Mapping[typing.Mapping[typing.Any]] = None,
  abstract: bool = None,
  transforms: typing.List[SmithyTransform] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.imports">imports</a></code> | <code>typing.List[str]</code> | List of imports. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.plugins">plugins</a></code> | <code>typing.Mapping[typing.Mapping[typing.Any]]</code> | Plugins keyed by plugin id. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.abstract">abstract</a></code> | <code>bool</code> | Whether or not the projection is abstract. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.transforms">transforms</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform">SmithyTransform</a>]</code> | Transforms to apply to the projection. |

---

##### `imports`<sup>Optional</sup> <a name="imports" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.imports"></a>

```python
imports: typing.List[str]
```

- *Type:* typing.List[str]

List of imports.

---

##### `plugins`<sup>Optional</sup> <a name="plugins" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.plugins"></a>

```python
plugins: typing.Mapping[typing.Mapping[typing.Any]]
```

- *Type:* typing.Mapping[typing.Mapping[typing.Any]]

Plugins keyed by plugin id.

---

##### `abstract`<sup>Optional</sup> <a name="abstract" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.abstract"></a>

```python
abstract: bool
```

- *Type:* bool

Whether or not the projection is abstract.

---

##### `transforms`<sup>Optional</sup> <a name="transforms" id="@aws-prototyping-sdk/type-safe-api.SmithyProjection.property.transforms"></a>

```python
transforms: typing.List[SmithyTransform]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform">SmithyTransform</a>]

Transforms to apply to the projection.

---

### SmithyServiceName <a name="SmithyServiceName" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName"></a>

Represents a fully qualified name of a Smithy service.

> [https://awslabs.github.io/smithy/2.0/spec/service-types.html](https://awslabs.github.io/smithy/2.0/spec/service-types.html)

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyServiceName(
  namespace: str,
  service_name: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.namespace">namespace</a></code> | <code>str</code> | The service namespace. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.serviceName">service_name</a></code> | <code>str</code> | The service name. |

---

##### `namespace`<sup>Required</sup> <a name="namespace" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.namespace"></a>

```python
namespace: str
```

- *Type:* str

The service namespace.

Nested namespaces are separated by '.', for example com.company

> [https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id](https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id)

---

##### `service_name`<sup>Required</sup> <a name="service_name" id="@aws-prototyping-sdk/type-safe-api.SmithyServiceName.property.serviceName"></a>

```python
service_name: str
```

- *Type:* str

The service name.

Should be PascalCase, for example HelloService

> [https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id](https://awslabs.github.io/smithy/2.0/spec/model.html#shape-id)

---

### SmithyTransform <a name="SmithyTransform" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform"></a>

A smithy build transform.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyTransform(
  args: typing.Mapping[typing.Any],
  name: str
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.args">args</a></code> | <code>typing.Mapping[typing.Any]</code> | Arguments for the transform. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.name">name</a></code> | <code>str</code> | Name of the transform. |

---

##### `args`<sup>Required</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.args"></a>

```python
args: typing.Mapping[typing.Any]
```

- *Type:* typing.Mapping[typing.Any]

Arguments for the transform.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.SmithyTransform.property.name"></a>

```python
name: str
```

- *Type:* str

Name of the transform.

---

### TypeSafeApiIntegration <a name="TypeSafeApiIntegration" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration"></a>

Defines an integration for an individual API operation.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiIntegration(
  integration: Integration,
  authorizer: Authorizer = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.integration">integration</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration">Integration</a></code> | The lambda function to service the api operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.authorizer">authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The authorizer to use for this api operation (overrides the default). |

---

##### `integration`<sup>Required</sup> <a name="integration" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.integration"></a>

```python
integration: Integration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Integration">Integration</a>

The lambda function to service the api operation.

---

##### `authorizer`<sup>Optional</sup> <a name="authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration.property.authorizer"></a>

```python
authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The authorizer to use for this api operation (overrides the default).

---

### TypeSafeApiModelProjectOptions <a name="TypeSafeApiModelProjectOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions"></a>

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiModelProjectOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  model_language: ModelLanguage,
  model_options: ModelOptions
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelLanguage">model_language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelOptions">model_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | *No description.* |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `model_language`<sup>Required</sup> <a name="model_language" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelLanguage"></a>

```python
model_language: ModelLanguage
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

---

##### `model_options`<sup>Required</sup> <a name="model_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProjectOptions.property.modelOptions"></a>

```python
model_options: ModelOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

---

### TypeSafeApiOptions <a name="TypeSafeApiOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions"></a>

Options required alongside an Open API specification to create API Gateway resources.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiOptions(
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[MethodAndPath],
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.integrations"></a>

```python
integrations: typing.Mapping[TypeSafeApiIntegration]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.operationLookup"></a>

```python
operation_lookup: typing.Mapping[MethodAndPath]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]

Details about each operation.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.corsOptions"></a>

```python
cors_options: CorsOptions
```

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiOptions.property.defaultAuthorizer"></a>

```python
default_authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

### TypeSafeApiProjectOptions <a name="TypeSafeApiProjectOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions"></a>

Options for the TypeSafeApiProject.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiProjectOptions(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  infrastructure: InfrastructureConfiguration,
  model: ModelConfiguration,
  runtime: RuntimeConfiguration,
  documentation: DocumentationConfiguration = None,
  library: LibraryConfiguration = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a></code> | Configuration for generated infrastructure. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a></code> | Configuration for the API model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a></code> | Configuration for generated runtime projects (containing types, clients and server code). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.documentation">documentation</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a></code> | Configuration for generated documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a></code> | Configuration for generated libraries. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.name"></a>

```python
name: str
```

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitIgnoreOptions"></a>

```python
git_ignore_options: IgnoreFileOptions
```

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.gitOptions"></a>

```python
git_options: GitOptions
```

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.logging"></a>

```python
logging: LoggerOptions
```

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.outdir"></a>

```python
outdir: str
```

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJson"></a>

```python
projenrc_json: bool
```

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.projenrcJsonOptions"></a>

```python
projenrc_json_options: ProjenrcJsonOptions
```

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebot"></a>

```python
renovatebot: bool
```

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.renovatebotOptions"></a>

```python
renovatebot_options: RenovatebotOptions
```

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.infrastructure"></a>

```python
infrastructure: InfrastructureConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a>

Configuration for generated infrastructure.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.model"></a>

```python
model: ModelConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a>

Configuration for the API model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.runtime"></a>

```python
runtime: RuntimeConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a>

Configuration for generated runtime projects (containing types, clients and server code).

---

##### `documentation`<sup>Optional</sup> <a name="documentation" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.documentation"></a>

```python
documentation: DocumentationConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a>

Configuration for generated documentation.

---

##### `library`<sup>Optional</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProjectOptions.property.library"></a>

```python
library: LibraryConfiguration
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a>

Configuration for generated libraries.

Libraries are projects which are generated from your model, but are not
fully-fledged runtimes, for example react hooks or clients in languages that aren't supported as runtimes.

---

### TypeSafeApiWebAclOptions <a name="TypeSafeApiWebAclOptions" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions"></a>

Configuration for the Web ACL associated with the API.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiWebAclOptions(
  cidr_allow_list: CidrAllowList = None,
  disable: bool = None,
  managed_rules: typing.List[ManagedRule] = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.cidrAllowList">cidr_allow_list</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList">CidrAllowList</a></code> | List of cidr ranges to allow. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.disable">disable</a></code> | <code>bool</code> | If set to true, no WebACL will be associated with the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.managedRules">managed_rules</a></code> | <code>typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule">ManagedRule</a>]</code> | List of managed rules to apply to the web acl. |

---

##### `cidr_allow_list`<sup>Optional</sup> <a name="cidr_allow_list" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.cidrAllowList"></a>

```python
cidr_allow_list: CidrAllowList
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CidrAllowList">CidrAllowList</a>
- *Default:* undefined

List of cidr ranges to allow.

---

##### `disable`<sup>Optional</sup> <a name="disable" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.disable"></a>

```python
disable: bool
```

- *Type:* bool
- *Default:* false

If set to true, no WebACL will be associated with the API.

You can also use this option if you would like to create
your own WebACL and associate it yourself.

---

##### `managed_rules`<sup>Optional</sup> <a name="managed_rules" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions.property.managedRules"></a>

```python
managed_rules: typing.List[ManagedRule]
```

- *Type:* typing.List[<a href="#@aws-prototyping-sdk/type-safe-api.ManagedRule">ManagedRule</a>]
- *Default:* [{ vendor: "AWS", name: "AWSManagedRulesCommonRuleSet" }]

List of managed rules to apply to the web acl.

---

### TypeSafeRestApiProps <a name="TypeSafeRestApiProps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps"></a>

Configuration for the TypeSafeRestApi construct.

#### Initializer <a name="Initializer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeRestApiProps(
  cloud_watch_role: bool = None,
  deploy: bool = None,
  deploy_options: StageOptions = None,
  description: str = None,
  disable_execute_api_endpoint: bool = None,
  domain_name: DomainNameOptions = None,
  endpoint_export_name: str = None,
  endpoint_types: typing.List[EndpointType] = None,
  fail_on_warnings: bool = None,
  parameters: typing.Mapping[str] = None,
  policy: PolicyDocument = None,
  rest_api_name: str = None,
  retain_deployments: bool = None,
  integrations: typing.Mapping[TypeSafeApiIntegration],
  operation_lookup: typing.Mapping[MethodAndPath],
  cors_options: CorsOptions = None,
  default_authorizer: Authorizer = None,
  spec_path: str,
  web_acl_options: TypeSafeApiWebAclOptions = None
)
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.cloudWatchRole">cloud_watch_role</a></code> | <code>bool</code> | Automatically configure an AWS CloudWatch role for API Gateway. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deploy">deploy</a></code> | <code>bool</code> | Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deployOptions">deploy_options</a></code> | <code>aws_cdk.aws_apigateway.StageOptions</code> | Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.description">description</a></code> | <code>str</code> | A description of the RestApi construct. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.disableExecuteApiEndpoint">disable_execute_api_endpoint</a></code> | <code>bool</code> | Specifies whether clients can invoke the API using the default execute-api endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.domainName">domain_name</a></code> | <code>aws_cdk.aws_apigateway.DomainNameOptions</code> | Configure a custom domain name and map it to this API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointExportName">endpoint_export_name</a></code> | <code>str</code> | Export name for the CfnOutput containing the API endpoint. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointTypes">endpoint_types</a></code> | <code>typing.List[aws_cdk.aws_apigateway.EndpointType]</code> | A list of the endpoint types of the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.failOnWarnings">fail_on_warnings</a></code> | <code>bool</code> | Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.parameters">parameters</a></code> | <code>typing.Mapping[str]</code> | Custom header parameters for the request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.policy">policy</a></code> | <code>aws_cdk.aws_iam.PolicyDocument</code> | A policy document that contains the permissions for this RestApi. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.restApiName">rest_api_name</a></code> | <code>str</code> | A name for the API Gateway RestApi resource. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.retainDeployments">retain_deployments</a></code> | <code>bool</code> | Retains old deployment resources when the API changes. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.integrations">integrations</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]</code> | A mapping of API operation to its integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.operationLookup">operation_lookup</a></code> | <code>typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]</code> | Details about each operation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.corsOptions">cors_options</a></code> | <code>aws_cdk.aws_apigateway.CorsOptions</code> | Cross Origin Resource Sharing options for the API. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.defaultAuthorizer">default_authorizer</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a></code> | The default authorizer to use for your api. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.specPath">spec_path</a></code> | <code>str</code> | Path to the JSON open api spec. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.webAclOptions">web_acl_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a></code> | Options for the AWS WAF v2 WebACL associated with the api. |

---

##### `cloud_watch_role`<sup>Optional</sup> <a name="cloud_watch_role" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.cloudWatchRole"></a>

```python
cloud_watch_role: bool
```

- *Type:* bool
- *Default:* false if `@aws-cdk/aws-apigateway:disableCloudWatchRole` is enabled, true otherwise

Automatically configure an AWS CloudWatch role for API Gateway.

---

##### `deploy`<sup>Optional</sup> <a name="deploy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deploy"></a>

```python
deploy: bool
```

- *Type:* bool
- *Default:* true

Indicates if a Deployment should be automatically created for this API, and recreated when the API model (resources, methods) changes.

Since API Gateway deployments are immutable, When this option is enabled
(by default), an AWS::ApiGateway::Deployment resource will automatically
created with a logical ID that hashes the API model (methods, resources
and options). This means that when the model changes, the logical ID of
this CloudFormation resource will change, and a new deployment will be
created.

If this is set, `latestDeployment` will refer to the `Deployment` object
and `deploymentStage` will refer to a `Stage` that points to this
deployment. To customize the stage options, use the `deployOptions`
property.

A CloudFormation Output will also be defined with the root URL endpoint
of this REST API.

---

##### `deploy_options`<sup>Optional</sup> <a name="deploy_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.deployOptions"></a>

```python
deploy_options: StageOptions
```

- *Type:* aws_cdk.aws_apigateway.StageOptions
- *Default:* Based on defaults of `StageOptions`.

Options for the API Gateway stage that will always point to the latest deployment when `deploy` is enabled.

If `deploy` is disabled,
this value cannot be set.

---

##### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.description"></a>

```python
description: str
```

- *Type:* str
- *Default:* 'Automatically created by the RestApi construct'

A description of the RestApi construct.

---

##### `disable_execute_api_endpoint`<sup>Optional</sup> <a name="disable_execute_api_endpoint" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.disableExecuteApiEndpoint"></a>

```python
disable_execute_api_endpoint: bool
```

- *Type:* bool
- *Default:* false

Specifies whether clients can invoke the API using the default execute-api endpoint.

To require that clients use a custom domain name to invoke the
API, disable the default endpoint.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html)

---

##### `domain_name`<sup>Optional</sup> <a name="domain_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.domainName"></a>

```python
domain_name: DomainNameOptions
```

- *Type:* aws_cdk.aws_apigateway.DomainNameOptions
- *Default:* no domain name is defined, use `addDomainName` or directly define a `DomainName`.

Configure a custom domain name and map it to this API.

---

##### `endpoint_export_name`<sup>Optional</sup> <a name="endpoint_export_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointExportName"></a>

```python
endpoint_export_name: str
```

- *Type:* str
- *Default:* when no export name is given, output will be created without export

Export name for the CfnOutput containing the API endpoint.

---

##### `endpoint_types`<sup>Optional</sup> <a name="endpoint_types" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.endpointTypes"></a>

```python
endpoint_types: typing.List[EndpointType]
```

- *Type:* typing.List[aws_cdk.aws_apigateway.EndpointType]
- *Default:* EndpointType.EDGE

A list of the endpoint types of the API.

Use this property when creating
an API.

---

##### `fail_on_warnings`<sup>Optional</sup> <a name="fail_on_warnings" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.failOnWarnings"></a>

```python
fail_on_warnings: bool
```

- *Type:* bool
- *Default:* false

Indicates whether to roll back the resource if a warning occurs while API Gateway is creating the RestApi resource.

---

##### `parameters`<sup>Optional</sup> <a name="parameters" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.parameters"></a>

```python
parameters: typing.Mapping[str]
```

- *Type:* typing.Mapping[str]
- *Default:* No parameters.

Custom header parameters for the request.

> [https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html](https://docs.aws.amazon.com/cli/latest/reference/apigateway/import-rest-api.html)

---

##### `policy`<sup>Optional</sup> <a name="policy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.policy"></a>

```python
policy: PolicyDocument
```

- *Type:* aws_cdk.aws_iam.PolicyDocument
- *Default:* No policy.

A policy document that contains the permissions for this RestApi.

---

##### `rest_api_name`<sup>Optional</sup> <a name="rest_api_name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.restApiName"></a>

```python
rest_api_name: str
```

- *Type:* str
- *Default:* ID of the RestApi construct.

A name for the API Gateway RestApi resource.

---

##### `retain_deployments`<sup>Optional</sup> <a name="retain_deployments" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.retainDeployments"></a>

```python
retain_deployments: bool
```

- *Type:* bool
- *Default:* false

Retains old deployment resources when the API changes.

This allows
manually reverting stages to point to old deployments via the AWS
Console.

---

##### `integrations`<sup>Required</sup> <a name="integrations" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.integrations"></a>

```python
integrations: typing.Mapping[TypeSafeApiIntegration]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiIntegration">TypeSafeApiIntegration</a>]

A mapping of API operation to its integration.

---

##### `operation_lookup`<sup>Required</sup> <a name="operation_lookup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.operationLookup"></a>

```python
operation_lookup: typing.Mapping[MethodAndPath]
```

- *Type:* typing.Mapping[<a href="#@aws-prototyping-sdk/type-safe-api.MethodAndPath">MethodAndPath</a>]

Details about each operation.

---

##### `cors_options`<sup>Optional</sup> <a name="cors_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.corsOptions"></a>

```python
cors_options: CorsOptions
```

- *Type:* aws_cdk.aws_apigateway.CorsOptions

Cross Origin Resource Sharing options for the API.

---

##### `default_authorizer`<sup>Optional</sup> <a name="default_authorizer" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.defaultAuthorizer"></a>

```python
default_authorizer: Authorizer
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.Authorizer">Authorizer</a>

The default authorizer to use for your api.

When omitted, no default authorizer is used.
Authorizers specified at the integration level will override this for that operation.

---

##### `spec_path`<sup>Required</sup> <a name="spec_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.specPath"></a>

```python
spec_path: str
```

- *Type:* str

Path to the JSON open api spec.

---

##### `web_acl_options`<sup>Optional</sup> <a name="web_acl_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeRestApiProps.property.webAclOptions"></a>

```python
web_acl_options: TypeSafeApiWebAclOptions
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiWebAclOptions">TypeSafeApiWebAclOptions</a>

Options for the AWS WAF v2 WebACL associated with the api.

By default, a Web ACL with the AWS default managed
rule set will be associated with the API. These options may disable or override the defaults.

---

## Classes <a name="Classes" id="Classes"></a>

### Authorizer <a name="Authorizer" id="@aws-prototyping-sdk/type-safe-api.Authorizer"></a>

An authorizer for authorizing API requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizer(
  authorization_type: AuthorizationType,
  authorizer_id: str,
  authorization_scopes: typing.List[str] = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationType"></a>

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizer.Initializer.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### Authorizers <a name="Authorizers" id="@aws-prototyping-sdk/type-safe-api.Authorizers"></a>

Class used to construct authorizers for use in the OpenApiGatewayLambdaApi construct.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Authorizers.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.cognito">cognito</a></code> | A Cognito User Pools authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.custom">custom</a></code> | A custom authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.iam">iam</a></code> | An IAM authorizer which uses AWS signature version 4 to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Authorizers.none">none</a></code> | No authorizer. |

---

##### `cognito` <a name="cognito" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.cognito(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

A Cognito User Pools authorizer.

###### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

###### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.userPools"></a>

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

###### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.Authorizers.cognito.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

##### `custom` <a name="custom" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.custom(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

A custom authorizer.

###### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

###### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.function"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

###### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.authorizerResultTtlInSeconds"></a>

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

###### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.identitySource"></a>

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

###### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.Authorizers.custom.parameter.type"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---

##### `iam` <a name="iam" id="@aws-prototyping-sdk/type-safe-api.Authorizers.iam"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.iam()
```

An IAM authorizer which uses AWS signature version 4 to authorize requests.

##### `none` <a name="none" id="@aws-prototyping-sdk/type-safe-api.Authorizers.none"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Authorizers.none()
```

No authorizer.



### CognitoAuthorizer <a name="CognitoAuthorizer" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer"></a>

An authorizer that uses Cognito identity or access tokens.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CognitoAuthorizer(
  authorizer_id: str,
  user_pools: typing.List[IUserPool],
  authorization_scopes: typing.List[str] = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | A list of authorization scopes configured on the method. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.userPools"></a>

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.Initializer.parameter.authorizationScopes"></a>

- *Type:* typing.List[str]
- *Default:* []

A list of authorization scopes configured on the method.

When used as the default authorizer, these scopes will be
applied to all methods without an authorizer at the integration level.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes">with_scopes</a></code> | Returns this authorizer with scopes applied, intended for usage in individual operations where scopes may differ on a per-operation basis. |

---

##### `with_scopes` <a name="with_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes"></a>

```python
def with_scopes(
  authorization_scopes: str
) -> CognitoAuthorizer
```

Returns this authorizer with scopes applied, intended for usage in individual operations where scopes may differ on a per-operation basis.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html#cfn-apigateway-method-authorizationscopes)

###### `authorization_scopes`<sup>Required</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.withScopes.parameter.authorizationScopes"></a>

- *Type:* str

the scopes to apply.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.userPools">user_pools</a></code> | <code>typing.List[aws_cdk.aws_cognito.IUserPool]</code> | The Cognito user pools associated with this authorizer. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

##### `user_pools`<sup>Required</sup> <a name="user_pools" id="@aws-prototyping-sdk/type-safe-api.CognitoAuthorizer.property.userPools"></a>

```python
user_pools: typing.List[IUserPool]
```

- *Type:* typing.List[aws_cdk.aws_cognito.IUserPool]

The Cognito user pools associated with this authorizer.

---


### CustomAuthorizer <a name="CustomAuthorizer" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer"></a>

An authorizer that uses a lambda function to authorize requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.CustomAuthorizer(
  authorizer_id: str,
  function: IFunction,
  authorizer_result_ttl_in_seconds: typing.Union[int, float] = None,
  identity_source: str = None,
  type: CustomAuthorizerType = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerId">authorizer_id</a></code> | <code>str</code> | Unique identifier for this authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerId"></a>

- *Type:* str

Unique identifier for this authorizer.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.function"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `authorizer_result_ttl_in_seconds`<sup>Optional</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.authorizerResultTtlInSeconds"></a>

- *Type:* typing.Union[int, float]
- *Default:* 300

The number of seconds during which the authorizer result is cached.

---

##### `identity_source`<sup>Optional</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.identitySource"></a>

- *Type:* str
- *Default:* "method.request.header.Authorization"

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Optional</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.Initializer.parameter.type"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>
- *Default:* CustomAuthorizerType.TOKEN

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerResultTtlInSeconds">authorizer_result_ttl_in_seconds</a></code> | <code>typing.Union[int, float]</code> | The number of seconds during which the authorizer result is cached. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.function">function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | The lambda function used to authorize requests. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.identitySource">identity_source</a></code> | <code>str</code> | The source of the identity in an incoming request. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.type">type</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a></code> | The type of custom authorizer. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---

##### `authorizer_result_ttl_in_seconds`<sup>Required</sup> <a name="authorizer_result_ttl_in_seconds" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.authorizerResultTtlInSeconds"></a>

```python
authorizer_result_ttl_in_seconds: typing.Union[int, float]
```

- *Type:* typing.Union[int, float]

The number of seconds during which the authorizer result is cached.

---

##### `function`<sup>Required</sup> <a name="function" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.function"></a>

```python
function: IFunction
```

- *Type:* aws_cdk.aws_lambda.IFunction

The lambda function used to authorize requests.

---

##### `identity_source`<sup>Required</sup> <a name="identity_source" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.identitySource"></a>

```python
identity_source: str
```

- *Type:* str

The source of the identity in an incoming request.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-identitysource)

---

##### `type`<sup>Required</sup> <a name="type" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizer.property.type"></a>

```python
type: CustomAuthorizerType
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType">CustomAuthorizerType</a>

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

---


### IamAuthorizer <a name="IamAuthorizer" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer"></a>

An IAM authorizer.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.IamAuthorizer()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.IamAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### Integration <a name="Integration" id="@aws-prototyping-sdk/type-safe-api.Integration"></a>

An integration for an API operation.

You can extend this to implement your own integration if you like.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Integration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integration()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration.grant">grant</a></code> | Grant permissions for the API to invoke the integration. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integration.render">render</a></code> | Render the integration into an API Gateway OpenAPI extension. |

---

##### `grant` <a name="grant" id="@aws-prototyping-sdk/type-safe-api.Integration.grant"></a>

```python
def grant(
  method: str,
  path: str,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
) -> None
```

Grant permissions for the API to invoke the integration.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.api"></a>

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.operationId"></a>

- *Type:* str

The ID of the operation for which permissions are being granted.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.Integration.grant.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

##### `render` <a name="render" id="@aws-prototyping-sdk/type-safe-api.Integration.render"></a>

```python
def render(
  method: str,
  path: str,
  operation_id: str,
  scope: Construct
) -> ApiGatewayIntegration
```

Render the integration into an API Gateway OpenAPI extension.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.operationId"></a>

- *Type:* str

The ID of the operation being rendered.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.Integration.render.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---




### Integrations <a name="Integrations" id="@aws-prototyping-sdk/type-safe-api.Integrations"></a>

A collection of integrations to connect API operations with a backend to service requests.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.Integrations.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integrations()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Integrations.lambda">lambda</a></code> | An integration that invokes a lambda function to service the request. |

---

##### `lambda` <a name="lambda" id="@aws-prototyping-sdk/type-safe-api.Integrations.lambda"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.Integrations.lambda(
  lambda_function: IFunction
)
```

An integration that invokes a lambda function to service the request.

###### `lambda_function`<sup>Required</sup> <a name="lambda_function" id="@aws-prototyping-sdk/type-safe-api.Integrations.lambda.parameter.lambdaFunction"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

the function to invoke.

---



### LambdaIntegration <a name="LambdaIntegration" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration"></a>

A lambda integration.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.LambdaIntegration(
  lambda_function: IFunction
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer.parameter.lambdaFunction">lambda_function</a></code> | <code>aws_cdk.aws_lambda.IFunction</code> | *No description.* |

---

##### `lambda_function`<sup>Required</sup> <a name="lambda_function" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.Initializer.parameter.lambdaFunction"></a>

- *Type:* aws_cdk.aws_lambda.IFunction

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant">grant</a></code> | Grant API Gateway permissions to invoke the lambda. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render">render</a></code> | Render the lambda integration as a snippet of OpenAPI. |

---

##### `grant` <a name="grant" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant"></a>

```python
def grant(
  method: str,
  path: str,
  api: SpecRestApi,
  operation_id: str,
  scope: Construct
) -> None
```

Grant API Gateway permissions to invoke the lambda.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `api`<sup>Required</sup> <a name="api" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.api"></a>

- *Type:* aws_cdk.aws_apigateway.SpecRestApi

The api to grant permissions for.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.operationId"></a>

- *Type:* str

The ID of the operation for which permissions are being granted.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.grant.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which permission resources can be created.

---

##### `render` <a name="render" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render"></a>

```python
def render(
  method: str,
  path: str,
  operation_id: str,
  scope: Construct
) -> ApiGatewayIntegration
```

Render the lambda integration as a snippet of OpenAPI.

###### `method`<sup>Required</sup> <a name="method" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.method"></a>

- *Type:* str

The http method of this operation.

---

###### `path`<sup>Required</sup> <a name="path" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.path"></a>

- *Type:* str

The path of this operation in the api.

---

###### `operation_id`<sup>Required</sup> <a name="operation_id" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.operationId"></a>

- *Type:* str

The ID of the operation being rendered.

---

###### `scope`<sup>Required</sup> <a name="scope" id="@aws-prototyping-sdk/type-safe-api.LambdaIntegration.render.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which the integration is being rendered.

---




### NoneAuthorizer <a name="NoneAuthorizer" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer"></a>

No authorizer.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.NoneAuthorizer()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationType">authorization_type</a></code> | <code>aws_cdk.aws_apigateway.AuthorizationType</code> | The type of the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizerId">authorizer_id</a></code> | <code>str</code> | The unique identifier for the authorizer. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationScopes">authorization_scopes</a></code> | <code>typing.List[str]</code> | Scopes for the authorizer, if any. |

---

##### `authorization_type`<sup>Required</sup> <a name="authorization_type" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationType"></a>

```python
authorization_type: AuthorizationType
```

- *Type:* aws_cdk.aws_apigateway.AuthorizationType

The type of the authorizer.

---

##### `authorizer_id`<sup>Required</sup> <a name="authorizer_id" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizerId"></a>

```python
authorizer_id: str
```

- *Type:* str

The unique identifier for the authorizer.

---

##### `authorization_scopes`<sup>Optional</sup> <a name="authorization_scopes" id="@aws-prototyping-sdk/type-safe-api.NoneAuthorizer.property.authorizationScopes"></a>

```python
authorization_scopes: typing.List[str]
```

- *Type:* typing.List[str]

Scopes for the authorizer, if any.

---


### OpenApiDefinition <a name="OpenApiDefinition" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition"></a>

The OpenAPI Spec.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.OpenApiDefinition(
  project: TypeSafeApiModelProject,
  open_api_options: OpenApiModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.project">project</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.openApiOptions">open_api_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a></code> | Options for the openapi model. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.project"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

---

##### `open_api_options`<sup>Required</sup> <a name="open_api_options" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.Initializer.parameter.openApiOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiModelOptions">OpenApiModelOptions</a>

Options for the openapi model.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.postSynthesize">post_synthesize</a></code> | Called after synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.preSynthesize">pre_synthesize</a></code> | Called before synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.synthesize">synthesize</a></code> | Synthesizes files to the project output directory. |

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after synthesis.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before synthesis.

##### `synthesize` <a name="synthesize" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.synthesize"></a>

```python
def synthesize() -> None
```

Synthesizes files to the project output directory.


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.project">project</a></code> | <code>projen.Project</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.openApiSpecificationPath">open_api_specification_path</a></code> | <code>str</code> | Path to the root OpenAPI specification file. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.project"></a>

```python
project: Project
```

- *Type:* projen.Project

---

##### `open_api_specification_path`<sup>Required</sup> <a name="open_api_specification_path" id="@aws-prototyping-sdk/type-safe-api.OpenApiDefinition.property.openApiSpecificationPath"></a>

```python
open_api_specification_path: str
```

- *Type:* str

Path to the root OpenAPI specification file.

---


### SmithyDefinition <a name="SmithyDefinition" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition"></a>

Creates a project which transforms a Smithy model to OpenAPI.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.SmithyDefinition(
  project: TypeSafeApiModelProject,
  smithy_options: SmithyModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.project">project</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.smithyOptions">smithy_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a></code> | Smithy engine options. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.project"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

---

##### `smithy_options`<sup>Required</sup> <a name="smithy_options" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.Initializer.parameter.smithyOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyModelOptions">SmithyModelOptions</a>

Smithy engine options.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.postSynthesize">post_synthesize</a></code> | Called after synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.preSynthesize">pre_synthesize</a></code> | Called before synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.synthesize">synthesize</a></code> | Synthesizes files to the project output directory. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps">add_deps</a></code> | Add maven-style or local file dependencies to the smithy model project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps">add_smithy_deps</a></code> | Add dependencies on other smithy models, such that their shapes can be imported in this project. |

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after synthesis.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before synthesis.

##### `synthesize` <a name="synthesize" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.synthesize"></a>

```python
def synthesize() -> None
```

Synthesizes files to the project output directory.

##### `add_deps` <a name="add_deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps"></a>

```python
def add_deps(
  deps: str
) -> None
```

Add maven-style or local file dependencies to the smithy model project.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addDeps.parameter.deps"></a>

- *Type:* str

dependencies to add, eg "software.amazon.smithy:smithy-validation-model:1.27.2" or "file://../some/path/build/lib/my-shapes.jar.

---

##### `add_smithy_deps` <a name="add_smithy_deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps"></a>

```python
def add_smithy_deps(
  deps: SmithyDefinition
) -> None
```

Add dependencies on other smithy models, such that their shapes can be imported in this project.

###### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.addSmithyDeps.parameter.deps"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a>

smithy definitions to depend on.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.project">project</a></code> | <code>projen.Project</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.gradleProjectName">gradle_project_name</a></code> | <code>str</code> | Name of the gradle project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.openApiSpecificationPath">open_api_specification_path</a></code> | <code>str</code> | Path to the generated OpenAPI specification, relative to the project outdir. |

---

##### `project`<sup>Required</sup> <a name="project" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.project"></a>

```python
project: Project
```

- *Type:* projen.Project

---

##### `gradle_project_name`<sup>Required</sup> <a name="gradle_project_name" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.gradleProjectName"></a>

```python
gradle_project_name: str
```

- *Type:* str

Name of the gradle project.

---

##### `open_api_specification_path`<sup>Required</sup> <a name="open_api_specification_path" id="@aws-prototyping-sdk/type-safe-api.SmithyDefinition.property.openApiSpecificationPath"></a>

```python
open_api_specification_path: str
```

- *Type:* str

Path to the generated OpenAPI specification, relative to the project outdir.

---


### TypeSafeApiModelProject <a name="TypeSafeApiModelProject" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject"></a>

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiModelProject(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  model_language: ModelLanguage,
  model_options: ModelOptions
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelLanguage">model_language</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelOptions">model_options</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a></code> | *No description.* |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.name"></a>

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.commitGenerated"></a>

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.gitOptions"></a>

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.logging"></a>

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.outdir"></a>

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.parent"></a>

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenCommand"></a>

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJson"></a>

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebot"></a>

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `model_language`<sup>Required</sup> <a name="model_language" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelLanguage"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage">ModelLanguage</a>

---

##### `model_options`<sup>Required</sup> <a name="model_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.Initializer.parameter.modelOptions"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelOptions">ModelOptions</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup">add_exclude_from_cleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore">add_git_ignore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore">add_package_ignore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask">add_task</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip">add_tip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated">annotate_generated</a></code> | Consider a set of files as "generated". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.postSynthesize">post_synthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.preSynthesize">pre_synthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask">remove_task</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand">run_task_command</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile">try_find_file</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile">try_find_json_file</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile">try_find_object_file</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile">try_remove_file</a></code> | Finds a file at the specified relative path within this project and removes it. |

---

##### `add_exclude_from_cleanup` <a name="add_exclude_from_cleanup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup"></a>

```python
def add_exclude_from_cleanup(
  globs: str
) -> None
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* str

The glob patterns to match.

---

##### `add_git_ignore` <a name="add_git_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore"></a>

```python
def add_git_ignore(
  pattern: str
) -> None
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addGitIgnore.parameter.pattern"></a>

- *Type:* str

The glob pattern to ignore.

---

##### `add_package_ignore` <a name="add_package_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore"></a>

```python
def add_package_ignore(
  _pattern: str
) -> None
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `_pattern`<sup>Required</sup> <a name="_pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addPackageIgnore.parameter._pattern"></a>

- *Type:* str

The glob pattern to exclude.

---

##### `add_task` <a name="add_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask"></a>

```python
def add_task(
  name: str,
  condition: str = None,
  cwd: str = None,
  description: str = None,
  env: typing.Mapping[str] = None,
  required_env: typing.List[str] = None,
  args: typing.List[str] = None,
  exec: str = None,
  receive_args: bool = None,
  steps: typing.List[TaskStep] = None
) -> Task
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.name"></a>

- *Type:* str

The task name to add.

---

###### `condition`<sup>Optional</sup> <a name="condition" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.condition"></a>

- *Type:* str

A shell command which determines if the this task should be executed.

If
the program exits with a zero exit code, steps will be executed. A non-zero
code means that task will be skipped.

---

###### `cwd`<sup>Optional</sup> <a name="cwd" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.cwd"></a>

- *Type:* str
- *Default:* process.cwd()

The working directory for all steps in this task (unless overridden by the step).

---

###### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.description"></a>

- *Type:* str
- *Default:* the task name

The description of this build command.

---

###### `env`<sup>Optional</sup> <a name="env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.env"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

Defines environment variables for the execution of this task.

Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.

---

###### `required_env`<sup>Optional</sup> <a name="required_env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.requiredEnv"></a>

- *Type:* typing.List[str]

A set of environment variables that must be defined in order to execute this task.

Task execution will fail if one of these is not defined.

---

###### `args`<sup>Optional</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.args"></a>

- *Type:* typing.List[str]
- *Default:* no arguments are passed to the step

Should the provided `exec` shell command receive fixed args.

> [{@link TaskStepOptions.args }]({@link TaskStepOptions.args })

---

###### `exec`<sup>Optional</sup> <a name="exec" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.exec"></a>

- *Type:* str
- *Default:* add steps using `task.exec(command)` or `task.spawn(subtask)`

Shell command to execute as the first command of the task.

---

###### `receive_args`<sup>Optional</sup> <a name="receive_args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.receiveArgs"></a>

- *Type:* bool
- *Default:* false

Should the provided `exec` shell command receive args passed to the task.

> [{@link TaskStepOptions.receiveArgs }]({@link TaskStepOptions.receiveArgs })

---

###### `steps`<sup>Optional</sup> <a name="steps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTask.parameter.steps"></a>

- *Type:* typing.List[projen.TaskStep]

List of task steps to run.

---

##### ~~`add_tip`~~ <a name="add_tip" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip"></a>

```python
def add_tip(
  message: str
) -> None
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.addTip.parameter.message"></a>

- *Type:* str

The message.

---

##### `annotate_generated` <a name="annotate_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated"></a>

```python
def annotate_generated(
  _glob: str
) -> None
```

Consider a set of files as "generated".

This method is implemented by
derived classes and used for example, to add git attributes to tell GitHub
that certain files are generated.

###### `_glob`<sup>Required</sup> <a name="_glob" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.annotateGenerated.parameter._glob"></a>

- *Type:* str

the glob pattern to match (could be a file path).

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before all components are synthesized.

##### `remove_task` <a name="remove_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask"></a>

```python
def remove_task(
  name: str
) -> Task
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.removeTask.parameter.name"></a>

- *Type:* str

The name of the task to remove.

---

##### `run_task_command` <a name="run_task_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand"></a>

```python
def run_task_command(
  task: Task
) -> str
```

Returns the shell command to execute in order to run a task.

By default, this is `npx projen@<version> <task>`

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.runTaskCommand.parameter.task"></a>

- *Type:* projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.synth"></a>

```python
def synth() -> None
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `try_find_file` <a name="try_find_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile"></a>

```python
def try_find_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`try_find_json_file`~~ <a name="try_find_json_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile"></a>

```python
def try_find_json_file(
  file_path: str
) -> JsonFile
```

Finds a json file by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_find_object_file` <a name="try_find_object_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile"></a>

```python
def try_find_object_file(
  file_path: str
) -> ObjectFile
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_remove_file` <a name="try_remove_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile"></a>

```python
def try_remove_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and removes it.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.buildTask">build_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.compileTask">compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.components">components</a></code> | <code>typing.List[projen.Component]</code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.deps">deps</a></code> | <code>projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.ejected">ejected</a></code> | <code>bool</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.files">files</a></code> | <code>typing.List[projen.FileBase]</code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitattributes">gitattributes</a></code> | <code>projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitignore">gitignore</a></code> | <code>projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.logger">logger</a></code> | <code>projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.name">name</a></code> | <code>str</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.outdir">outdir</a></code> | <code>str</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.packageTask">package_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.postCompileTask">post_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.preCompileTask">pre_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projectBuild">project_build</a></code> | <code>projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projenCommand">projen_command</a></code> | <code>str</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.root">root</a></code> | <code>projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.subprojects">subprojects</a></code> | <code>typing.List[projen.Project]</code> | Returns all the subprojects within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.tasks">tasks</a></code> | <code>projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.testTask">test_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.defaultTask">default_task</a></code> | <code>projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.initProject">init_project</a></code> | <code>projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parent">parent</a></code> | <code>projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.generateTask">generate_task</a></code> | <code>projen.Task</code> | Reference to the task used for generating the final bundled OpenAPI specification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parsedSpecFile">parsed_spec_file</a></code> | <code>str</code> | Name of the final bundled OpenAPI specification. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.openapi">openapi</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition">OpenApiDefinition</a></code> | Reference to the OpenAPI definition component. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.smithy">smithy</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a></code> | Reference to the Smithy definition component. |

---

##### `build_task`<sup>Required</sup> <a name="build_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.buildTask"></a>

```python
build_task: Task
```

- *Type:* projen.Task

---

##### `commit_generated`<sup>Required</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool

Whether to commit the managed files by default.

---

##### `compile_task`<sup>Required</sup> <a name="compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.compileTask"></a>

```python
compile_task: Task
```

- *Type:* projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.components"></a>

```python
components: typing.List[Component]
```

- *Type:* typing.List[projen.Component]

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.deps"></a>

```python
deps: Dependencies
```

- *Type:* projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.ejected"></a>

```python
ejected: bool
```

- *Type:* bool

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.files"></a>

```python
files: typing.List[FileBase]
```

- *Type:* typing.List[projen.FileBase]

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitattributes"></a>

```python
gitattributes: GitAttributesFile
```

- *Type:* projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.gitignore"></a>

```python
gitignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.logger"></a>

```python
logger: Logger
```

- *Type:* projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.name"></a>

```python
name: str
```

- *Type:* str

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.outdir"></a>

```python
outdir: str
```

- *Type:* str

Absolute output directory of this project.

---

##### `package_task`<sup>Required</sup> <a name="package_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.packageTask"></a>

```python
package_task: Task
```

- *Type:* projen.Task

---

##### `post_compile_task`<sup>Required</sup> <a name="post_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.postCompileTask"></a>

```python
post_compile_task: Task
```

- *Type:* projen.Task

---

##### `pre_compile_task`<sup>Required</sup> <a name="pre_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.preCompileTask"></a>

```python
pre_compile_task: Task
```

- *Type:* projen.Task

---

##### `project_build`<sup>Required</sup> <a name="project_build" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projectBuild"></a>

```python
project_build: ProjectBuild
```

- *Type:* projen.ProjectBuild

Manages the build process of the project.

---

##### `projen_command`<sup>Required</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.root"></a>

```python
root: Project
```

- *Type:* projen.Project

The root project.

---

##### `subprojects`<sup>Required</sup> <a name="subprojects" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.subprojects"></a>

```python
subprojects: typing.List[Project]
```

- *Type:* typing.List[projen.Project]

Returns all the subprojects within this project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.tasks"></a>

```python
tasks: Tasks
```

- *Type:* projen.Tasks

Project tasks.

---

##### `test_task`<sup>Required</sup> <a name="test_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.testTask"></a>

```python
test_task: Task
```

- *Type:* projen.Task

---

##### `default_task`<sup>Optional</sup> <a name="default_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.defaultTask"></a>

```python
default_task: Task
```

- *Type:* projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `init_project`<sup>Optional</sup> <a name="init_project" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.initProject"></a>

```python
init_project: InitProject
```

- *Type:* projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

A parent project.

If undefined, this is the root project.

---

##### `generate_task`<sup>Required</sup> <a name="generate_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.generateTask"></a>

```python
generate_task: Task
```

- *Type:* projen.Task

Reference to the task used for generating the final bundled OpenAPI specification.

---

##### `parsed_spec_file`<sup>Required</sup> <a name="parsed_spec_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.parsedSpecFile"></a>

```python
parsed_spec_file: str
```

- *Type:* str

Name of the final bundled OpenAPI specification.

---

##### `openapi`<sup>Optional</sup> <a name="openapi" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.openapi"></a>

```python
openapi: OpenApiDefinition
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.OpenApiDefinition">OpenApiDefinition</a>

Reference to the OpenAPI definition component.

Will be defined if the model language is OpenAPI

---

##### `smithy`<sup>Optional</sup> <a name="smithy" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.smithy"></a>

```python
smithy: SmithyDefinition
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.SmithyDefinition">SmithyDefinition</a>

Reference to the Smithy definition component.

Will be defined if the model language is Smithy

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>str</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject.property.DEFAULT_TASK"></a>

```python
DEFAULT_TASK: str
```

- *Type:* str

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---

### TypeSafeApiProject <a name="TypeSafeApiProject" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject"></a>

Project for a type-safe API, defined using Smithy or OpenAPI.

Generates a CDK construct to deploy your API, as well as client and server code to help build your API quickly.

#### Initializers <a name="Initializers" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer"></a>

```python
import aws_prototyping_sdk.type_safe_api

aws_prototyping_sdk.type_safe_api.TypeSafeApiProject(
  name: str,
  commit_generated: bool = None,
  git_ignore_options: IgnoreFileOptions = None,
  git_options: GitOptions = None,
  logging: LoggerOptions = None,
  outdir: str = None,
  parent: Project = None,
  projen_command: str = None,
  projenrc_json: bool = None,
  projenrc_json_options: ProjenrcJsonOptions = None,
  renovatebot: bool = None,
  renovatebot_options: RenovatebotOptions = None,
  infrastructure: InfrastructureConfiguration,
  model: ModelConfiguration,
  runtime: RuntimeConfiguration,
  documentation: DocumentationConfiguration = None,
  library: LibraryConfiguration = None
)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.name">name</a></code> | <code>str</code> | This is the name of your project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitIgnoreOptions">git_ignore_options</a></code> | <code>projen.IgnoreFileOptions</code> | Configuration options for .gitignore file. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitOptions">git_options</a></code> | <code>projen.GitOptions</code> | Configuration options for git. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.logging">logging</a></code> | <code>projen.LoggerOptions</code> | Configure logging options such as verbosity. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.outdir">outdir</a></code> | <code>str</code> | The root directory of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.parent">parent</a></code> | <code>projen.Project</code> | The parent project, if this project is part of a bigger project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenCommand">projen_command</a></code> | <code>str</code> | The shell command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJson">projenrc_json</a></code> | <code>bool</code> | Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJsonOptions">projenrc_json_options</a></code> | <code>projen.ProjenrcJsonOptions</code> | Options for .projenrc.json. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebot">renovatebot</a></code> | <code>bool</code> | Use renovatebot to handle dependency upgrades. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebotOptions">renovatebot_options</a></code> | <code>projen.RenovatebotOptions</code> | Options for renovatebot. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a></code> | Configuration for generated infrastructure. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a></code> | Configuration for the API model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a></code> | Configuration for generated runtime projects (containing types, clients and server code). |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.documentation">documentation</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a></code> | Configuration for generated documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a></code> | Configuration for generated libraries. |

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.name"></a>

- *Type:* str
- *Default:* $BASEDIR

This is the name of your project.

---

##### `commit_generated`<sup>Optional</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.commitGenerated"></a>

- *Type:* bool
- *Default:* true

Whether to commit the managed files by default.

---

##### `git_ignore_options`<sup>Optional</sup> <a name="git_ignore_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitIgnoreOptions"></a>

- *Type:* projen.IgnoreFileOptions

Configuration options for .gitignore file.

---

##### `git_options`<sup>Optional</sup> <a name="git_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.gitOptions"></a>

- *Type:* projen.GitOptions

Configuration options for git.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.logging"></a>

- *Type:* projen.LoggerOptions
- *Default:* {}

Configure logging options such as verbosity.

---

##### `outdir`<sup>Optional</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.outdir"></a>

- *Type:* str
- *Default:* "."

The root directory of the project.

Relative to this directory, all files are synthesized.

If this project has a parent, this directory is relative to the parent
directory and it cannot be the same as the parent or any of it's other
sub-projects.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.parent"></a>

- *Type:* projen.Project

The parent project, if this project is part of a bigger project.

---

##### `projen_command`<sup>Optional</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenCommand"></a>

- *Type:* str
- *Default:* "npx projen"

The shell command to use in order to run the projen CLI.

Can be used to customize in special environments.

---

##### `projenrc_json`<sup>Optional</sup> <a name="projenrc_json" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJson"></a>

- *Type:* bool
- *Default:* false

Generate (once) .projenrc.json (in JSON). Set to `false` in order to disable .projenrc.json generation.

---

##### `projenrc_json_options`<sup>Optional</sup> <a name="projenrc_json_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.projenrcJsonOptions"></a>

- *Type:* projen.ProjenrcJsonOptions
- *Default:* default options

Options for .projenrc.json.

---

##### `renovatebot`<sup>Optional</sup> <a name="renovatebot" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebot"></a>

- *Type:* bool
- *Default:* false

Use renovatebot to handle dependency upgrades.

---

##### `renovatebot_options`<sup>Optional</sup> <a name="renovatebot_options" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.renovatebotOptions"></a>

- *Type:* projen.RenovatebotOptions
- *Default:* default options

Options for renovatebot.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.infrastructure"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.InfrastructureConfiguration">InfrastructureConfiguration</a>

Configuration for generated infrastructure.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.model"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.ModelConfiguration">ModelConfiguration</a>

Configuration for the API model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.runtime"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.RuntimeConfiguration">RuntimeConfiguration</a>

Configuration for generated runtime projects (containing types, clients and server code).

---

##### `documentation`<sup>Optional</sup> <a name="documentation" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.documentation"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.DocumentationConfiguration">DocumentationConfiguration</a>

Configuration for generated documentation.

---

##### `library`<sup>Optional</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.Initializer.parameter.library"></a>

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.LibraryConfiguration">LibraryConfiguration</a>

Configuration for generated libraries.

Libraries are projects which are generated from your model, but are not
fully-fledged runtimes, for example react hooks or clients in languages that aren't supported as runtimes.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup">add_exclude_from_cleanup</a></code> | Exclude the matching files from pre-synth cleanup. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore">add_git_ignore</a></code> | Adds a .gitignore pattern. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore">add_package_ignore</a></code> | Exclude these files from the bundled package. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask">add_task</a></code> | Adds a new task to this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip">add_tip</a></code> | Prints a "tip" message during synthesis. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated">annotate_generated</a></code> | Consider a set of files as "generated". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.postSynthesize">post_synthesize</a></code> | Called after all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.preSynthesize">pre_synthesize</a></code> | Called before all components are synthesized. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask">remove_task</a></code> | Removes a task from a project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand">run_task_command</a></code> | Returns the shell command to execute in order to run a task. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.synth">synth</a></code> | Synthesize all project files into `outdir`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile">try_find_file</a></code> | Finds a file at the specified relative path within this project and all its subprojects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile">try_find_json_file</a></code> | Finds a json file by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile">try_find_object_file</a></code> | Finds an object file (like JsonFile, YamlFile, etc.) by name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile">try_remove_file</a></code> | Finds a file at the specified relative path within this project and removes it. |

---

##### `add_exclude_from_cleanup` <a name="add_exclude_from_cleanup" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup"></a>

```python
def add_exclude_from_cleanup(
  globs: str
) -> None
```

Exclude the matching files from pre-synth cleanup.

Can be used when, for example, some
source files include the projen marker and we don't want them to be erased during synth.

###### `globs`<sup>Required</sup> <a name="globs" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addExcludeFromCleanup.parameter.globs"></a>

- *Type:* str

The glob patterns to match.

---

##### `add_git_ignore` <a name="add_git_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore"></a>

```python
def add_git_ignore(
  pattern: str
) -> None
```

Adds a .gitignore pattern.

###### `pattern`<sup>Required</sup> <a name="pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addGitIgnore.parameter.pattern"></a>

- *Type:* str

The glob pattern to ignore.

---

##### `add_package_ignore` <a name="add_package_ignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore"></a>

```python
def add_package_ignore(
  _pattern: str
) -> None
```

Exclude these files from the bundled package.

Implemented by project types based on the
packaging mechanism. For example, `NodeProject` delegates this to `.npmignore`.

###### `_pattern`<sup>Required</sup> <a name="_pattern" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addPackageIgnore.parameter._pattern"></a>

- *Type:* str

The glob pattern to exclude.

---

##### `add_task` <a name="add_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask"></a>

```python
def add_task(
  name: str,
  condition: str = None,
  cwd: str = None,
  description: str = None,
  env: typing.Mapping[str] = None,
  required_env: typing.List[str] = None,
  args: typing.List[str] = None,
  exec: str = None,
  receive_args: bool = None,
  steps: typing.List[TaskStep] = None
) -> Task
```

Adds a new task to this project.

This will fail if the project already has
a task with this name.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.name"></a>

- *Type:* str

The task name to add.

---

###### `condition`<sup>Optional</sup> <a name="condition" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.condition"></a>

- *Type:* str

A shell command which determines if the this task should be executed.

If
the program exits with a zero exit code, steps will be executed. A non-zero
code means that task will be skipped.

---

###### `cwd`<sup>Optional</sup> <a name="cwd" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.cwd"></a>

- *Type:* str
- *Default:* process.cwd()

The working directory for all steps in this task (unless overridden by the step).

---

###### `description`<sup>Optional</sup> <a name="description" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.description"></a>

- *Type:* str
- *Default:* the task name

The description of this build command.

---

###### `env`<sup>Optional</sup> <a name="env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.env"></a>

- *Type:* typing.Mapping[str]
- *Default:* {}

Defines environment variables for the execution of this task.

Values in this map will be evaluated in a shell, so you can do stuff like `$(echo "foo")`.

---

###### `required_env`<sup>Optional</sup> <a name="required_env" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.requiredEnv"></a>

- *Type:* typing.List[str]

A set of environment variables that must be defined in order to execute this task.

Task execution will fail if one of these is not defined.

---

###### `args`<sup>Optional</sup> <a name="args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.args"></a>

- *Type:* typing.List[str]
- *Default:* no arguments are passed to the step

Should the provided `exec` shell command receive fixed args.

> [{@link TaskStepOptions.args }]({@link TaskStepOptions.args })

---

###### `exec`<sup>Optional</sup> <a name="exec" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.exec"></a>

- *Type:* str
- *Default:* add steps using `task.exec(command)` or `task.spawn(subtask)`

Shell command to execute as the first command of the task.

---

###### `receive_args`<sup>Optional</sup> <a name="receive_args" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.receiveArgs"></a>

- *Type:* bool
- *Default:* false

Should the provided `exec` shell command receive args passed to the task.

> [{@link TaskStepOptions.receiveArgs }]({@link TaskStepOptions.receiveArgs })

---

###### `steps`<sup>Optional</sup> <a name="steps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTask.parameter.steps"></a>

- *Type:* typing.List[projen.TaskStep]

List of task steps to run.

---

##### ~~`add_tip`~~ <a name="add_tip" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip"></a>

```python
def add_tip(
  message: str
) -> None
```

Prints a "tip" message during synthesis.

###### `message`<sup>Required</sup> <a name="message" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.addTip.parameter.message"></a>

- *Type:* str

The message.

---

##### `annotate_generated` <a name="annotate_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated"></a>

```python
def annotate_generated(
  _glob: str
) -> None
```

Consider a set of files as "generated".

This method is implemented by
derived classes and used for example, to add git attributes to tell GitHub
that certain files are generated.

###### `_glob`<sup>Required</sup> <a name="_glob" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.annotateGenerated.parameter._glob"></a>

- *Type:* str

the glob pattern to match (could be a file path).

---

##### `post_synthesize` <a name="post_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.postSynthesize"></a>

```python
def post_synthesize() -> None
```

Called after all components are synthesized.

Order is *not* guaranteed.

##### `pre_synthesize` <a name="pre_synthesize" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.preSynthesize"></a>

```python
def pre_synthesize() -> None
```

Called before all components are synthesized.

##### `remove_task` <a name="remove_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask"></a>

```python
def remove_task(
  name: str
) -> Task
```

Removes a task from a project.

###### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.removeTask.parameter.name"></a>

- *Type:* str

The name of the task to remove.

---

##### `run_task_command` <a name="run_task_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand"></a>

```python
def run_task_command(
  task: Task
) -> str
```

Returns the shell command to execute in order to run a task.

By default, this is `npx projen@<version> <task>`

###### `task`<sup>Required</sup> <a name="task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.runTaskCommand.parameter.task"></a>

- *Type:* projen.Task

The task for which the command is required.

---

##### `synth` <a name="synth" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.synth"></a>

```python
def synth() -> None
```

Synthesize all project files into `outdir`.

1. Call "this.preSynthesize()"
2. Delete all generated files
3. Synthesize all sub-projects
4. Synthesize all components of this project
5. Call "postSynthesize()" for all components of this project
6. Call "this.postSynthesize()"

##### `try_find_file` <a name="try_find_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile"></a>

```python
def try_find_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and all its subprojects.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be resolved
from the root of _this_ project.

---

##### ~~`try_find_json_file`~~ <a name="try_find_json_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile"></a>

```python
def try_find_json_file(
  file_path: str
) -> JsonFile
```

Finds a json file by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindJsonFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_find_object_file` <a name="try_find_object_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile"></a>

```python
def try_find_object_file(
  file_path: str
) -> ObjectFile
```

Finds an object file (like JsonFile, YamlFile, etc.) by name.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryFindObjectFile.parameter.filePath"></a>

- *Type:* str

The file path.

---

##### `try_remove_file` <a name="try_remove_file" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile"></a>

```python
def try_remove_file(
  file_path: str
) -> FileBase
```

Finds a file at the specified relative path within this project and removes it.

###### `file_path`<sup>Required</sup> <a name="file_path" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.tryRemoveFile.parameter.filePath"></a>

- *Type:* str

The file path.

If this path is relative, it will be
resolved from the root of _this_ project.

---


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.buildTask">build_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.commitGenerated">commit_generated</a></code> | <code>bool</code> | Whether to commit the managed files by default. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.compileTask">compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.components">components</a></code> | <code>typing.List[projen.Component]</code> | Returns all the components within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.deps">deps</a></code> | <code>projen.Dependencies</code> | Project dependencies. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.ejected">ejected</a></code> | <code>bool</code> | Whether or not the project is being ejected. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.files">files</a></code> | <code>typing.List[projen.FileBase]</code> | All files in this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitattributes">gitattributes</a></code> | <code>projen.GitAttributesFile</code> | The .gitattributes file for this repository. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitignore">gitignore</a></code> | <code>projen.IgnoreFile</code> | .gitignore. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.logger">logger</a></code> | <code>projen.Logger</code> | Logging utilities. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.name">name</a></code> | <code>str</code> | Project name. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.outdir">outdir</a></code> | <code>str</code> | Absolute output directory of this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.packageTask">package_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.postCompileTask">post_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.preCompileTask">pre_compile_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projectBuild">project_build</a></code> | <code>projen.ProjectBuild</code> | Manages the build process of the project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projenCommand">projen_command</a></code> | <code>str</code> | The command to use in order to run the projen CLI. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.root">root</a></code> | <code>projen.Project</code> | The root project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.subprojects">subprojects</a></code> | <code>typing.List[projen.Project]</code> | Returns all the subprojects within this project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.tasks">tasks</a></code> | <code>projen.Tasks</code> | Project tasks. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.testTask">test_task</a></code> | <code>projen.Task</code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.defaultTask">default_task</a></code> | <code>projen.Task</code> | This is the "default" task, the one that executes "projen". |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.initProject">init_project</a></code> | <code>projen.InitProject</code> | The options used when this project is bootstrapped via `projen new`. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.parent">parent</a></code> | <code>projen.Project</code> | A parent project. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.infrastructure">infrastructure</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a></code> | Generated infrastructure projects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.library">library</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects">GeneratedLibraryProjects</a></code> | Generated library projects. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.model">model</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a></code> | Project for the api model. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.runtime">runtime</a></code> | <code><a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a></code> | Generated runtime projects. |

---

##### `build_task`<sup>Required</sup> <a name="build_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.buildTask"></a>

```python
build_task: Task
```

- *Type:* projen.Task

---

##### `commit_generated`<sup>Required</sup> <a name="commit_generated" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.commitGenerated"></a>

```python
commit_generated: bool
```

- *Type:* bool

Whether to commit the managed files by default.

---

##### `compile_task`<sup>Required</sup> <a name="compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.compileTask"></a>

```python
compile_task: Task
```

- *Type:* projen.Task

---

##### `components`<sup>Required</sup> <a name="components" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.components"></a>

```python
components: typing.List[Component]
```

- *Type:* typing.List[projen.Component]

Returns all the components within this project.

---

##### `deps`<sup>Required</sup> <a name="deps" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.deps"></a>

```python
deps: Dependencies
```

- *Type:* projen.Dependencies

Project dependencies.

---

##### `ejected`<sup>Required</sup> <a name="ejected" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.ejected"></a>

```python
ejected: bool
```

- *Type:* bool

Whether or not the project is being ejected.

---

##### `files`<sup>Required</sup> <a name="files" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.files"></a>

```python
files: typing.List[FileBase]
```

- *Type:* typing.List[projen.FileBase]

All files in this project.

---

##### `gitattributes`<sup>Required</sup> <a name="gitattributes" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitattributes"></a>

```python
gitattributes: GitAttributesFile
```

- *Type:* projen.GitAttributesFile

The .gitattributes file for this repository.

---

##### `gitignore`<sup>Required</sup> <a name="gitignore" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.gitignore"></a>

```python
gitignore: IgnoreFile
```

- *Type:* projen.IgnoreFile

.gitignore.

---

##### `logger`<sup>Required</sup> <a name="logger" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.logger"></a>

```python
logger: Logger
```

- *Type:* projen.Logger

Logging utilities.

---

##### `name`<sup>Required</sup> <a name="name" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.name"></a>

```python
name: str
```

- *Type:* str

Project name.

---

##### `outdir`<sup>Required</sup> <a name="outdir" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.outdir"></a>

```python
outdir: str
```

- *Type:* str

Absolute output directory of this project.

---

##### `package_task`<sup>Required</sup> <a name="package_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.packageTask"></a>

```python
package_task: Task
```

- *Type:* projen.Task

---

##### `post_compile_task`<sup>Required</sup> <a name="post_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.postCompileTask"></a>

```python
post_compile_task: Task
```

- *Type:* projen.Task

---

##### `pre_compile_task`<sup>Required</sup> <a name="pre_compile_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.preCompileTask"></a>

```python
pre_compile_task: Task
```

- *Type:* projen.Task

---

##### `project_build`<sup>Required</sup> <a name="project_build" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projectBuild"></a>

```python
project_build: ProjectBuild
```

- *Type:* projen.ProjectBuild

Manages the build process of the project.

---

##### `projen_command`<sup>Required</sup> <a name="projen_command" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.projenCommand"></a>

```python
projen_command: str
```

- *Type:* str

The command to use in order to run the projen CLI.

---

##### `root`<sup>Required</sup> <a name="root" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.root"></a>

```python
root: Project
```

- *Type:* projen.Project

The root project.

---

##### `subprojects`<sup>Required</sup> <a name="subprojects" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.subprojects"></a>

```python
subprojects: typing.List[Project]
```

- *Type:* typing.List[projen.Project]

Returns all the subprojects within this project.

---

##### `tasks`<sup>Required</sup> <a name="tasks" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.tasks"></a>

```python
tasks: Tasks
```

- *Type:* projen.Tasks

Project tasks.

---

##### `test_task`<sup>Required</sup> <a name="test_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.testTask"></a>

```python
test_task: Task
```

- *Type:* projen.Task

---

##### `default_task`<sup>Optional</sup> <a name="default_task" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.defaultTask"></a>

```python
default_task: Task
```

- *Type:* projen.Task

This is the "default" task, the one that executes "projen".

Undefined if
the project is being ejected.

---

##### `init_project`<sup>Optional</sup> <a name="init_project" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.initProject"></a>

```python
init_project: InitProject
```

- *Type:* projen.InitProject

The options used when this project is bootstrapped via `projen new`.

It
includes the original set of options passed to the CLI and also the JSII
FQN of the project type.

---

##### `parent`<sup>Optional</sup> <a name="parent" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.parent"></a>

```python
parent: Project
```

- *Type:* projen.Project

A parent project.

If undefined, this is the root project.

---

##### `infrastructure`<sup>Required</sup> <a name="infrastructure" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.infrastructure"></a>

```python
infrastructure: GeneratedCodeProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a>

Generated infrastructure projects.

Only the property corresponding to `infrastructure.language` will be defined.

---

##### `library`<sup>Required</sup> <a name="library" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.library"></a>

```python
library: GeneratedLibraryProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedLibraryProjects">GeneratedLibraryProjects</a>

Generated library projects.

Only the properties corresponding to specified `library.libraries` will be defined.

---

##### `model`<sup>Required</sup> <a name="model" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.model"></a>

```python
model: TypeSafeApiModelProject
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiModelProject">TypeSafeApiModelProject</a>

Project for the api model.

---

##### `runtime`<sup>Required</sup> <a name="runtime" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.runtime"></a>

```python
runtime: GeneratedCodeProjects
```

- *Type:* <a href="#@aws-prototyping-sdk/type-safe-api.GeneratedCodeProjects">GeneratedCodeProjects</a>

Generated runtime projects.

When `runtime.languages` includes the corresponding language, the project can be
assumed to be defined.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.DEFAULT_TASK">DEFAULT_TASK</a></code> | <code>str</code> | The name of the default task (the task executed when `projen` is run without arguments). |

---

##### `DEFAULT_TASK`<sup>Required</sup> <a name="DEFAULT_TASK" id="@aws-prototyping-sdk/type-safe-api.TypeSafeApiProject.property.DEFAULT_TASK"></a>

```python
DEFAULT_TASK: str
```

- *Type:* str

The name of the default task (the task executed when `projen` is run without arguments).

Normally
this task should synthesize the project files.

---


## Enums <a name="Enums" id="Enums"></a>

### CustomAuthorizerType <a name="CustomAuthorizerType" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType"></a>

The type of custom authorizer.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-authorizer.html#cfn-apigateway-authorizer-type)

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.TOKEN">TOKEN</a></code> | A custom authorizer that uses a Lambda function. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.REQUEST">REQUEST</a></code> | An authorizer that uses a Lambda function using incoming request parameters. |

---

##### `TOKEN` <a name="TOKEN" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.TOKEN"></a>

A custom authorizer that uses a Lambda function.

---


##### `REQUEST` <a name="REQUEST" id="@aws-prototyping-sdk/type-safe-api.CustomAuthorizerType.REQUEST"></a>

An authorizer that uses a Lambda function using incoming request parameters.

---


### DocumentationFormat <a name="DocumentationFormat" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat"></a>

Formats for documentation generation.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML_REDOC">HTML_REDOC</a></code> | HTML Documentation generated by redoc. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML2">HTML2</a></code> | OpenAPI Generator 'html2' documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.MARKDOWN">MARKDOWN</a></code> | OpenAPI Generator 'markdown' documentation. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.DocumentationFormat.PLANTUML">PLANTUML</a></code> | OpenAPI Generator 'plantuml' documentation. |

---

##### `HTML_REDOC` <a name="HTML_REDOC" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML_REDOC"></a>

HTML Documentation generated by redoc.

> [https://github.com/Redocly/redoc](https://github.com/Redocly/redoc)

---


##### `HTML2` <a name="HTML2" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.HTML2"></a>

OpenAPI Generator 'html2' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/html2.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/html2.md)

---


##### `MARKDOWN` <a name="MARKDOWN" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.MARKDOWN"></a>

OpenAPI Generator 'markdown' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/markdown.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/markdown.md)

---


##### `PLANTUML` <a name="PLANTUML" id="@aws-prototyping-sdk/type-safe-api.DocumentationFormat.PLANTUML"></a>

OpenAPI Generator 'plantuml' documentation.

> [https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/plantuml.md](https://github.com/OpenAPITools/openapi-generator/blob/master/docs/generators/plantuml.md)

---


### Language <a name="Language" id="@aws-prototyping-sdk/type-safe-api.Language"></a>

Supported languages for runtimes and infrastructure.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.TYPESCRIPT">TYPESCRIPT</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.PYTHON">PYTHON</a></code> | *No description.* |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Language.JAVA">JAVA</a></code> | *No description.* |

---

##### `TYPESCRIPT` <a name="TYPESCRIPT" id="@aws-prototyping-sdk/type-safe-api.Language.TYPESCRIPT"></a>

---


##### `PYTHON` <a name="PYTHON" id="@aws-prototyping-sdk/type-safe-api.Language.PYTHON"></a>

---


##### `JAVA` <a name="JAVA" id="@aws-prototyping-sdk/type-safe-api.Language.JAVA"></a>

---


### Library <a name="Library" id="@aws-prototyping-sdk/type-safe-api.Library"></a>

Supported libraries for code generation.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.Library.TYPESCRIPT_REACT_QUERY_HOOKS">TYPESCRIPT_REACT_QUERY_HOOKS</a></code> | *No description.* |

---

##### `TYPESCRIPT_REACT_QUERY_HOOKS` <a name="TYPESCRIPT_REACT_QUERY_HOOKS" id="@aws-prototyping-sdk/type-safe-api.Library.TYPESCRIPT_REACT_QUERY_HOOKS"></a>

---


### ModelLanguage <a name="ModelLanguage" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage"></a>

The model definition language.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage.SMITHY">SMITHY</a></code> | Smithy. |
| <code><a href="#@aws-prototyping-sdk/type-safe-api.ModelLanguage.OPENAPI">OPENAPI</a></code> | OpenAPI. |

---

##### `SMITHY` <a name="SMITHY" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage.SMITHY"></a>

Smithy.

> [https://smithy.io/2.0/](https://smithy.io/2.0/)

---


##### `OPENAPI` <a name="OPENAPI" id="@aws-prototyping-sdk/type-safe-api.ModelLanguage.OPENAPI"></a>

OpenAPI.

> [https://www.openapis.org/](https://www.openapis.org/)

---

